You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@flex.apache.org by ah...@apache.org on 2015/01/28 18:22:10 UTC

[02/12] git commit: [flex-asjs] [refs/heads/develop] - switching from org.apache.flex to org_apache_flex so GCC doesn't complain

http://git-wip-us.apache.org/repos/asf/flex-asjs/blob/49f207c4/frameworks/js/FlexJS/src/org/apache/flex/maps/google/Map.js
----------------------------------------------------------------------
diff --git a/frameworks/js/FlexJS/src/org/apache/flex/maps/google/Map.js b/frameworks/js/FlexJS/src/org/apache/flex/maps/google/Map.js
index a53b8f1..b2f49db 100644
--- a/frameworks/js/FlexJS/src/org/apache/flex/maps/google/Map.js
+++ b/frameworks/js/FlexJS/src/org/apache/flex/maps/google/Map.js
@@ -12,14 +12,14 @@
  * limitations under the License.
  */
 
-goog.provide('org.apache.flex.maps.google.Map');
+goog.provide('org_apache_flex_maps_google_Map');
 
-goog.require('org.apache.flex.core.IBeadModel');
-goog.require('org.apache.flex.maps.google.Geometry');
-goog.require('org.apache.flex.maps.google.LatLng');
-goog.require('org.apache.flex.maps.google.Marker');
-goog.require('org.apache.flex.maps.google.Place');
-goog.require('org.apache.flex.maps.google.models.MapModel');
+goog.require('org_apache_flex_core_IBeadModel');
+goog.require('org_apache_flex_maps_google_Geometry');
+goog.require('org_apache_flex_maps_google_LatLng');
+goog.require('org_apache_flex_maps_google_Marker');
+goog.require('org_apache_flex_maps_google_Place');
+goog.require('org_apache_flex_maps_google_models_MapModel');
 
 
 // IMPORTANT:
@@ -30,14 +30,14 @@ goog.require('org.apache.flex.maps.google.models.MapModel');
 
 /**
  * @constructor
- * @extends {org.apache.flex.core.UIBase}
+ * @extends {org_apache_flex_core_UIBase}
  */
-org.apache.flex.maps.google.Map = function() {
-  org.apache.flex.maps.google.Map.base(this, 'constructor');
+org_apache_flex_maps_google_Map = function() {
+  org_apache_flex_maps_google_Map.base(this, 'constructor');
   this.initialized = false;
 };
-goog.inherits(org.apache.flex.maps.google.Map,
-    org.apache.flex.core.UIBase);
+goog.inherits(org_apache_flex_maps_google_Map,
+    org_apache_flex_core_UIBase);
 
 
 /**
@@ -45,17 +45,17 @@ goog.inherits(org.apache.flex.maps.google.Map,
  *
  * @type {Object.<string, Array.<Object>>}
  */
-org.apache.flex.maps.google.Map.prototype.
+org_apache_flex_maps_google_Map.prototype.
 FLEXJS_CLASS_INFO =
 { names: [{ name: 'Map',
-           qName: 'org.apache.flex.maps.google.Map' }],
+           qName: 'org_apache_flex_maps_google_Map' }],
     interfaces: [] };
 
 
 /**
  *
  */
-org.apache.flex.maps.google.Map.prototype.searchResults = null;
+org_apache_flex_maps_google_Map.prototype.searchResults = null;
 
 
 /**
@@ -63,10 +63,10 @@ org.apache.flex.maps.google.Map.prototype.searchResults = null;
  * @protected
  * @return {Object} The actual element to be parented.
  */
-org.apache.flex.maps.google.Map.prototype.createElement =
+org_apache_flex_maps_google_Map.prototype.createElement =
     function() {
 
-  var model = new org.apache.flex.maps.google.models.MapModel();
+  var model = new org_apache_flex_maps_google_models_MapModel();
   this.addBead(model);
 
   this.element = document.createElement('div');
@@ -83,7 +83,7 @@ org.apache.flex.maps.google.Map.prototype.createElement =
  * @expose
  * @param {String} value Google API dev token.
  */
-org.apache.flex.maps.google.Map.prototype.set_token = function(value) {
+org_apache_flex_maps_google_Map.prototype.set_token = function(value) {
   this.token = value;
 };
 
@@ -92,7 +92,7 @@ org.apache.flex.maps.google.Map.prototype.set_token = function(value) {
  * @expose
  * @return {Object} The marker that was last selected.
  */
-org.apache.flex.maps.google.Map.prototype.get_selectedMarker =
+org_apache_flex_maps_google_Map.prototype.get_selectedMarker =
 function() {
   return this._selectedMarker;
 };
@@ -100,7 +100,7 @@ function() {
 
 /**
  */
-org.apache.flex.maps.google.Map.prototype.finishInitalization = function() {
+org_apache_flex_maps_google_Map.prototype.finishInitalization = function() {
   this.loadMap(37.333, -121.900, 12);
   this.initialized = true;
   this.dispatchEvent('ready');
@@ -113,7 +113,7 @@ org.apache.flex.maps.google.Map.prototype.finishInitalization = function() {
  * @param {number} centerLong center longitude.
  * @param {number} zoom zoom level.
  */
-org.apache.flex.maps.google.Map.prototype.loadMap =
+org_apache_flex_maps_google_Map.prototype.loadMap =
     function(centerLat, centerLong, zoom) {
   if (!this.initialized) {
     this.currentCenter = new window['google']['maps']['LatLng'](centerLat, centerLong);
@@ -133,7 +133,7 @@ org.apache.flex.maps.google.Map.prototype.loadMap =
  * @expose
  * @param {Number} zoomLevel The level of magnification.
  */
-org.apache.flex.maps.google.Map.prototype.setZoom =
+org_apache_flex_maps_google_Map.prototype.setZoom =
     function(zoomLevel) {
   if (this.initialized) {
     this.map.setZoom(zoomLevel);
@@ -145,7 +145,7 @@ org.apache.flex.maps.google.Map.prototype.setZoom =
  * @expose
  * @param {string} address The new center of the map.
  */
-org.apache.flex.maps.google.Map.prototype.centerOnAddress = function(address) {
+org_apache_flex_maps_google_Map.prototype.centerOnAddress = function(address) {
   if (!this.geocoder) this.geocoder = new window['google']['maps']['Geocoder']();
   this.geocoder.geocode({ 'address': address}, goog.bind(this.positionHandler, this));
 };
@@ -155,7 +155,7 @@ org.apache.flex.maps.google.Map.prototype.centerOnAddress = function(address) {
  * @expose
  * @param {Object} location The new center of the map.
  */
-org.apache.flex.maps.google.Map.prototype.setCenter = function(location) {
+org_apache_flex_maps_google_Map.prototype.setCenter = function(location) {
   this.currentCenter = new window['google']['maps']['LatLng'](location.lat, location.lng);
   this.map.setCenter(this.currentCenter);
 };
@@ -164,7 +164,7 @@ org.apache.flex.maps.google.Map.prototype.setCenter = function(location) {
 /**
  * @expose
  */
-org.apache.flex.maps.google.Map.prototype.markCurrentLocation = function() {
+org_apache_flex_maps_google_Map.prototype.markCurrentLocation = function() {
   this.createMarker(this.currentCenter);
 };
 
@@ -173,7 +173,7 @@ org.apache.flex.maps.google.Map.prototype.markCurrentLocation = function() {
  * @expose
  * @param {string} address The address to locate and mark on the map.
  */
-org.apache.flex.maps.google.Map.prototype.markAddress =
+org_apache_flex_maps_google_Map.prototype.markAddress =
     function(address) {
   if (this.initialized) {
     if (!this.geocoder) this.geocoder = new window['google']['maps']['Geocoder']();
@@ -187,7 +187,7 @@ org.apache.flex.maps.google.Map.prototype.markAddress =
  * @param {Object} location A LatLng that denotes the position of the marker.
  * @return {Object} A marker object.
  */
-org.apache.flex.maps.google.Map.prototype.createMarker =
+org_apache_flex_maps_google_Map.prototype.createMarker =
     function(location) {
   var marker = new window['google']['maps']['Marker']({
     map: this.map,
@@ -202,7 +202,7 @@ org.apache.flex.maps.google.Map.prototype.createMarker =
  * @expose
  * @param {string} placeName A place to search for.
  */
-org.apache.flex.maps.google.Map.prototype.nearbySearch =
+org_apache_flex_maps_google_Map.prototype.nearbySearch =
     function(placeName) {
   if (this.markers == null) this.markers = [];
   this.service = new window['google']['maps']['places']['PlacesService'](this.map);
@@ -215,7 +215,7 @@ org.apache.flex.maps.google.Map.prototype.nearbySearch =
 /**
  * @expose
  */
-org.apache.flex.maps.google.Map.prototype.clearSearchResults =
+org_apache_flex_maps_google_Map.prototype.clearSearchResults =
 function() {
   if (this.markers) {
     for (var i = 0; i < this.markers.length; i++) {
@@ -230,9 +230,9 @@ function() {
  * @param {Object} marker The marker that was clicked.
  * @param {Object} event The mouse event for the marker click.
  */
-org.apache.flex.maps.google.Map.prototype.markerClicked =
+org_apache_flex_maps_google_Map.prototype.markerClicked =
 function(marker, event) {
-  var newMarker = new org.apache.flex.maps.google.Marker();
+  var newMarker = new org_apache_flex_maps_google_Marker();
   newMarker.position.lat = marker.position.lat();
   newMarker.position.lng = marker.position.lng();
   newMarker.title = marker.title;
@@ -240,7 +240,7 @@ function(marker, event) {
 
   this._selectedMarker = newMarker;
 
-  var newEvent = new org.apache.flex.events.Event('markerClicked');
+  var newEvent = new org_apache_flex_events_Event('markerClicked');
   newEvent.marker = newMarker;
   this.dispatchEvent(newEvent);
 };
@@ -250,7 +250,7 @@ function(marker, event) {
  * @param {Array} results The found location(s).
  * @param {string} status Status of the call.
  */
-org.apache.flex.maps.google.Map.prototype.positionHandler =
+org_apache_flex_maps_google_Map.prototype.positionHandler =
     function(results, status) {
   if (status == window['google']['maps']['GeocoderStatus']['OK']) {
     this.currentCenter = results[0]['geometry']['location'];
@@ -269,7 +269,7 @@ org.apache.flex.maps.google.Map.prototype.positionHandler =
  * @param {Array} results The found location(s).
  * @param {string} status Status of the call.
  */
-org.apache.flex.maps.google.Map.prototype.geoCodeHandler =
+org_apache_flex_maps_google_Map.prototype.geoCodeHandler =
     function(results, status) {
   if (status == window['google']['maps']['GeocoderStatus']['OK']) {
     this.currentCenter = results[0]['geometry']['location'];
@@ -288,12 +288,12 @@ org.apache.flex.maps.google.Map.prototype.geoCodeHandler =
  * @param {Array} results The result of the search.
  * @param {string} status Status of the search.
  */
-org.apache.flex.maps.google.Map.prototype.searchResultHandler =
+org_apache_flex_maps_google_Map.prototype.searchResultHandler =
 function(results, status) {
   this.searchResults = [];
   if (status == window['google']['maps']['places']['PlacesServiceStatus']['OK']) {
     for (var i = 0; i < results.length; i++) {
-      var place = new org.apache.flex.maps.google.Place();
+      var place = new org_apache_flex_maps_google_Place();
       place.geometry.location.lat = results[i]['geometry']['location']['lat'];
       place.geometry.location.lng = results[i]['geometry']['location']['lng'];
       place.icon = results[i]['icon'];
@@ -317,11 +317,11 @@ function(results, status) {
 /**
  * Handles changes in map center
  */
-org.apache.flex.maps.google.Map.prototype.centerChangeHandler =
+org_apache_flex_maps_google_Map.prototype.centerChangeHandler =
     function() {
   this.currentCenter = this.map['getCenter']();
 
-  var newEvent = new org.apache.flex.events.Event('centered');
+  var newEvent = new org_apache_flex_events_Event('centered');
   this.dispatchEvent(newEvent);
 };
 
@@ -329,11 +329,11 @@ org.apache.flex.maps.google.Map.prototype.centerChangeHandler =
 /**
  * Handles changes in map bounds
  */
-org.apache.flex.maps.google.Map.prototype.boundsChangeHandler =
+org_apache_flex_maps_google_Map.prototype.boundsChangeHandler =
     function() {
   this.currentCenter = this.map['getCenter']();
 
-  var newEvent = new org.apache.flex.events.Event('boundsChanged');
+  var newEvent = new org_apache_flex_events_Event('boundsChanged');
   this.dispatchEvent(newEvent);
 };
 
@@ -341,10 +341,10 @@ org.apache.flex.maps.google.Map.prototype.boundsChangeHandler =
 /**
  * Handles changes in map bounds
  */
-org.apache.flex.maps.google.Map.prototype.zoomChangeHandler =
+org_apache_flex_maps_google_Map.prototype.zoomChangeHandler =
     function() {
   this.currentCenter = this.map['getCenter']();
 
-  var newEvent = new org.apache.flex.events.Event('zoomChanged');
+  var newEvent = new org_apache_flex_events_Event('zoomChanged');
   this.dispatchEvent(newEvent);
 };

http://git-wip-us.apache.org/repos/asf/flex-asjs/blob/49f207c4/frameworks/js/FlexJS/src/org/apache/flex/maps/google/Marker.js
----------------------------------------------------------------------
diff --git a/frameworks/js/FlexJS/src/org/apache/flex/maps/google/Marker.js b/frameworks/js/FlexJS/src/org/apache/flex/maps/google/Marker.js
index 1332b24..36b14da 100644
--- a/frameworks/js/FlexJS/src/org/apache/flex/maps/google/Marker.js
+++ b/frameworks/js/FlexJS/src/org/apache/flex/maps/google/Marker.js
@@ -12,9 +12,9 @@
  * limitations under the License.
  */
 
-goog.provide('org.apache.flex.maps.google.Marker');
+goog.provide('org_apache_flex_maps_google_Marker');
 
-goog.require('org.apache.flex.maps.google.LatLng');
+goog.require('org_apache_flex_maps_google_LatLng');
 
 
 
@@ -27,8 +27,8 @@ goog.require('org.apache.flex.maps.google.LatLng');
 /**
  * @constructor
  */
-org.apache.flex.maps.google.Marker = function() {
-  this.position = new org.apache.flex.maps.google.LatLng();
+org_apache_flex_maps_google_Marker = function() {
+  this.position = new org_apache_flex_maps_google_LatLng();
 };
 
 
@@ -37,27 +37,27 @@ org.apache.flex.maps.google.Marker = function() {
  *
  * @type {Object.<string, Array.<Object>>}
  */
-org.apache.flex.maps.google.Marker.prototype.
+org_apache_flex_maps_google_Marker.prototype.
 FLEXJS_CLASS_INFO =
 { names: [{ name: 'Marker',
-           qName: 'org.apache.flex.maps.google.Marker' }],
+           qName: 'org_apache_flex_maps_google_Marker' }],
     interfaces: [] };
 
 
 /**
  * @type {Object} The marker's location.
  */
-org.apache.flex.maps.google.Marker.prototype.position = null;
+org_apache_flex_maps_google_Marker.prototype.position = null;
 
 
 /**
  * @type {String} The title for the marker.
  */
-org.apache.flex.maps.google.Marker.prototype.title = null;
+org_apache_flex_maps_google_Marker.prototype.title = null;
 
 
 /**
  * @type {Object} The map to which the marker belongs.
  */
-org.apache.flex.maps.google.Marker.prototype.map = null;
+org_apache_flex_maps_google_Marker.prototype.map = null;
 

http://git-wip-us.apache.org/repos/asf/flex-asjs/blob/49f207c4/frameworks/js/FlexJS/src/org/apache/flex/maps/google/Place.js
----------------------------------------------------------------------
diff --git a/frameworks/js/FlexJS/src/org/apache/flex/maps/google/Place.js b/frameworks/js/FlexJS/src/org/apache/flex/maps/google/Place.js
index 4aff636..482df0e 100644
--- a/frameworks/js/FlexJS/src/org/apache/flex/maps/google/Place.js
+++ b/frameworks/js/FlexJS/src/org/apache/flex/maps/google/Place.js
@@ -12,9 +12,9 @@
  * limitations under the License.
  */
 
-goog.provide('org.apache.flex.maps.google.Place');
+goog.provide('org_apache_flex_maps_google_Place');
 
-goog.require('org.apache.flex.maps.google.Geometry');
+goog.require('org_apache_flex_maps_google_Geometry');
 
 
 // IMPORTANT:
@@ -26,8 +26,8 @@ goog.require('org.apache.flex.maps.google.Geometry');
 /**
  * @constructor
  */
-org.apache.flex.maps.google.Place = function() {
-  this.geometry = new org.apache.flex.maps.google.Geometry();
+org_apache_flex_maps_google_Place = function() {
+  this.geometry = new org_apache_flex_maps_google_Geometry();
 };
 
 
@@ -36,54 +36,54 @@ org.apache.flex.maps.google.Place = function() {
  *
  * @type {Object.<string, Array.<Object>>}
  */
-org.apache.flex.maps.google.Place.prototype.
+org_apache_flex_maps_google_Place.prototype.
 FLEXJS_CLASS_INFO =
 { names: [{ name: 'Place',
-           qName: 'org.apache.flex.maps.google.Place' }],
+           qName: 'org_apache_flex_maps_google_Place' }],
     interfaces: [] };
 
 
 /**
  * @type {Object} The current location
  */
-org.apache.flex.maps.google.Place.prototype.geometry = null;
+org_apache_flex_maps_google_Place.prototype.geometry = null;
 
 
 /**
  * @type {String} The icon representing the place.
  */
-org.apache.flex.maps.google.Place.prototype.icon = null;
+org_apache_flex_maps_google_Place.prototype.icon = null;
 
 
 /**
  * @type {String} A unique identifier for the place.
  */
-org.apache.flex.maps.google.Place.prototype.id = null;
+org_apache_flex_maps_google_Place.prototype.id = null;
 
 
 /**
  * @type {String} The name of the place.
  */
-org.apache.flex.maps.google.Place.prototype.name = null;
+org_apache_flex_maps_google_Place.prototype.name = null;
 
 
 /**
  * @type {String} A reference identifier.
  */
-org.apache.flex.maps.google.Place.prototype.reference = null;
+org_apache_flex_maps_google_Place.prototype.reference = null;
 
 
 /**
  * @type {String} A description of the area of the place.
  */
-org.apache.flex.maps.google.Place.prototype.vicinity = null;
+org_apache_flex_maps_google_Place.prototype.vicinity = null;
 
 
 /**
  * @override
  * @return {string} A description of the area of the place.
  */
-org.apache.flex.maps.google.Place.prototype.toString = function PlaceToString() {
+org_apache_flex_maps_google_Place.prototype.toString = function PlaceToString() {
   var results = '';
   if (this.name) results = this.name;
   if (this.vicinity) results += ' ' + this.vicinity;

http://git-wip-us.apache.org/repos/asf/flex-asjs/blob/49f207c4/frameworks/js/FlexJS/src/org/apache/flex/maps/google/beads/MapView.js
----------------------------------------------------------------------
diff --git a/frameworks/js/FlexJS/src/org/apache/flex/maps/google/beads/MapView.js b/frameworks/js/FlexJS/src/org/apache/flex/maps/google/beads/MapView.js
index c388802..5088712 100644
--- a/frameworks/js/FlexJS/src/org/apache/flex/maps/google/beads/MapView.js
+++ b/frameworks/js/FlexJS/src/org/apache/flex/maps/google/beads/MapView.js
@@ -14,14 +14,14 @@
 /* MapView isn't really the view, but is a bead used to trigger
    the loading of the map JS files */
 
-goog.provide('org.apache.flex.maps.google.beads.MapView');
+goog.provide('org_apache_flex_maps_google_beads_MapView');
 
 
 
 /**
  * @constructor
  */
-org.apache.flex.maps.google.beads.MapView = function() {
+org_apache_flex_maps_google_beads_MapView = function() {
 };
 
 
@@ -30,18 +30,18 @@ org.apache.flex.maps.google.beads.MapView = function() {
  *
  * @type {Object.<string, Array.<Object>>}
  */
-org.apache.flex.maps.google.beads.MapView.prototype.
+org_apache_flex_maps_google_beads_MapView.prototype.
 FLEXJS_CLASS_INFO =
 { names: [{ name: 'MapView',
-           qName: 'org.apache.flex.maps.google.beads.MapView' }],
-    interfaces: [org.apache.flex.core.IBeadView] };
+           qName: 'org_apache_flex_maps_google_beads_MapView' }],
+    interfaces: [org_apache_flex_core_IBeadView] };
 
 
 /**
  * @expose
  * @param {Object} value The new host.
  */
-org.apache.flex.maps.google.beads.MapView.prototype.set_strand =
+org_apache_flex_maps_google_beads_MapView.prototype.set_strand =
 function(value) {
 
   this.strand_ = value;

http://git-wip-us.apache.org/repos/asf/flex-asjs/blob/49f207c4/frameworks/js/FlexJS/src/org/apache/flex/maps/google/models/MapModel.js
----------------------------------------------------------------------
diff --git a/frameworks/js/FlexJS/src/org/apache/flex/maps/google/models/MapModel.js b/frameworks/js/FlexJS/src/org/apache/flex/maps/google/models/MapModel.js
index eff4856..3956ab5 100644
--- a/frameworks/js/FlexJS/src/org/apache/flex/maps/google/models/MapModel.js
+++ b/frameworks/js/FlexJS/src/org/apache/flex/maps/google/models/MapModel.js
@@ -12,10 +12,10 @@
  * limitations under the License.
  */
 
-goog.provide('org.apache.flex.maps.google.models.MapModel');
+goog.provide('org_apache_flex_maps_google_models_MapModel');
 
-goog.require('org.apache.flex.core.IBeadModel');
-goog.require('org.apache.flex.events.EventDispatcher');
+goog.require('org_apache_flex_core_IBeadModel');
+goog.require('org_apache_flex_events_EventDispatcher');
 
 
 // IMPORTANT:
@@ -26,15 +26,15 @@ goog.require('org.apache.flex.events.EventDispatcher');
 
 /**
  * @constructor
- * @extends {org.apache.flex.events.EventDispatcher}
- * @implements {org.apache.flex.core.IBeadModel}
+ * @extends {org_apache_flex_events_EventDispatcher}
+ * @implements {org_apache_flex_core_IBeadModel}
  */
-org.apache.flex.maps.google.models.MapModel = function() {
-  org.apache.flex.maps.google.models.MapModel.base(this, 'constructor');
+org_apache_flex_maps_google_models_MapModel = function() {
+  org_apache_flex_maps_google_models_MapModel.base(this, 'constructor');
 };
 goog.inherits(
-    org.apache.flex.maps.google.models.MapModel,
-    org.apache.flex.events.EventDispatcher);
+    org_apache_flex_maps_google_models_MapModel,
+    org_apache_flex_events_EventDispatcher);
 
 
 /**
@@ -42,18 +42,18 @@ goog.inherits(
  *
  * @type {Object.<string, Array.<Object>>}
  */
-org.apache.flex.maps.google.models.MapModel.prototype.
+org_apache_flex_maps_google_models_MapModel.prototype.
 FLEXJS_CLASS_INFO =
 { names: [{ name: 'MapModel',
-           qName: 'org.apache.flex.maps.google.models.MapModel' }],
-    interfaces: [org.apache.flex.core.IBeadModel] };
+           qName: 'org_apache_flex_maps_google_models_MapModel' }],
+    interfaces: [org_apache_flex_core_IBeadModel] };
 
 
 /**
  * @expose
  * @param {Object} value The strand.
  */
-org.apache.flex.maps.google.models.MapModel.prototype.
+org_apache_flex_maps_google_models_MapModel.prototype.
     set_strand = function(value) {
   this.strand_ = value;
 };
@@ -63,7 +63,7 @@ org.apache.flex.maps.google.models.MapModel.prototype.
  * @expose
  * @return {Array} The search results list.
  */
-org.apache.flex.maps.google.models.MapModel.prototype.get_searchResults =
+org_apache_flex_maps_google_models_MapModel.prototype.get_searchResults =
 function() {
   return this._searchResults;
 };
@@ -73,7 +73,7 @@ function() {
  * @expose
  * @param {Array} value A list of search results.
  */
-org.apache.flex.maps.google.models.MapModel.prototype.set_searchResults =
+org_apache_flex_maps_google_models_MapModel.prototype.set_searchResults =
 function(value) {
   this._searchResults = value;
   this.dispatchEvent('searchResultsChanged');
@@ -84,7 +84,7 @@ function(value) {
  * @expose
  * @return {Number} Map zoom level.
  */
-org.apache.flex.maps.google.models.MapModel.prototype.get_zoom =
+org_apache_flex_maps_google_models_MapModel.prototype.get_zoom =
 function() {
   return this._zoom;
 };
@@ -94,7 +94,7 @@ function() {
  * @expose
  * @param {Number} value Map zoom level.
  */
-org.apache.flex.maps.google.models.MapModel.prototype.set_zoom =
+org_apache_flex_maps_google_models_MapModel.prototype.set_zoom =
 function(value) {
   this._zoom = value;
   this.dispatchEvent('zoomChanged');
@@ -105,7 +105,7 @@ function(value) {
  * @expose
  * @return {Object} The currently selected map Marker.
  */
-org.apache.flex.maps.google.models.MapModel.prototype.get_selectedMarker =
+org_apache_flex_maps_google_models_MapModel.prototype.get_selectedMarker =
 function() {
   return this._selectedMarker;
 };
@@ -115,7 +115,7 @@ function() {
  * @expose
  * @param {Object} value A marker to be made the selected marker.
  */
-org.apache.flex.maps.google.models.MapModel.prototype.set_selectedMarker =
+org_apache_flex_maps_google_models_MapModel.prototype.set_selectedMarker =
 function(value) {
   this._selectedMarker = value;
   this.dispatchEvent('selectedMarkerChanged');
@@ -126,7 +126,7 @@ function(value) {
  * @expose
  * @return {Object} The map's current center.
  */
-org.apache.flex.maps.google.models.MapModel.prototype.get_currentLocation =
+org_apache_flex_maps_google_models_MapModel.prototype.get_currentLocation =
 function() {
   return this._currentLocation;
 };
@@ -136,7 +136,7 @@ function() {
  * @expose
  * @param {Object} value The map's new current center.
  */
-org.apache.flex.maps.google.models.MapModel.prototype.set_currentLocation =
+org_apache_flex_maps_google_models_MapModel.prototype.set_currentLocation =
 function(value) {
   this._currentLocation = value;
   this.dispatchEvent('currentLocationChanged');

http://git-wip-us.apache.org/repos/asf/flex-asjs/blob/49f207c4/frameworks/js/FlexJS/src/org/apache/flex/net/BinaryUploader.js
----------------------------------------------------------------------
diff --git a/frameworks/js/FlexJS/src/org/apache/flex/net/BinaryUploader.js b/frameworks/js/FlexJS/src/org/apache/flex/net/BinaryUploader.js
index 8cff850..14cfe9f 100644
--- a/frameworks/js/FlexJS/src/org/apache/flex/net/BinaryUploader.js
+++ b/frameworks/js/FlexJS/src/org/apache/flex/net/BinaryUploader.js
@@ -12,19 +12,19 @@
  * limitations under the License.
  */
 
-goog.provide('org.apache.flex.net.BinaryUploader');
+goog.provide('org_apache_flex_net_BinaryUploader');
 
-goog.require('org.apache.flex.core.HTMLElementWrapper');
-goog.require('org.apache.flex.net.HTTPHeader');
+goog.require('org_apache_flex_core_HTMLElementWrapper');
+goog.require('org_apache_flex_net_HTTPHeader');
 
 
 
 /**
  * @constructor
- * @extends {org.apache.flex.core.HTMLElementWrapper}
+ * @extends {org_apache_flex_core_HTMLElementWrapper}
  */
-org.apache.flex.net.BinaryUploader = function() {
-  org.apache.flex.net.BinaryUploader .base(this, 'constructor');
+org_apache_flex_net_BinaryUploader = function() {
+  org_apache_flex_net_BinaryUploader .base(this, 'constructor');
 
   /**
    * @private
@@ -87,8 +87,8 @@ org.apache.flex.net.BinaryUploader = function() {
 
   this.element = new XMLHttpRequest();
 };
-goog.inherits(org.apache.flex.net.BinaryUploader,
-    org.apache.flex.core.HTMLElementWrapper);
+goog.inherits(org_apache_flex_net_BinaryUploader,
+    org_apache_flex_core_HTMLElementWrapper);
 
 
 /**
@@ -96,62 +96,62 @@ goog.inherits(org.apache.flex.net.BinaryUploader,
  *
  * @type {Object.<string, Array.<Object>>}
  */
-org.apache.flex.net.BinaryUploader.prototype.FLEXJS_CLASS_INFO =
+org_apache_flex_net_BinaryUploader.prototype.FLEXJS_CLASS_INFO =
     { names: [{ name: 'BinaryUploader',
-                qName: 'org.apache.flex.net.BinaryUploader'}] };
+                qName: 'org_apache_flex_net_BinaryUploader'}] };
 
 
 /**
  * @expose
  * @type {string}
  */
-org.apache.flex.net.BinaryUploader.HTTP_METHOD_GET = 'GET';
+org_apache_flex_net_BinaryUploader.HTTP_METHOD_GET = 'GET';
 
 
 /**
  * @expose
  * @type {string}
  */
-org.apache.flex.net.BinaryUploader.HTTP_METHOD_POST = 'POST';
+org_apache_flex_net_BinaryUploader.HTTP_METHOD_POST = 'POST';
 
 
 /**
  * @expose
  * @type {string}
  */
-org.apache.flex.net.BinaryUploader.HTTP_METHOD_PUT = 'PUT';
+org_apache_flex_net_BinaryUploader.HTTP_METHOD_PUT = 'PUT';
 
 
 /**
  * @expose
  * @type {string}
  */
-org.apache.flex.net.BinaryUploader.HTTP_METHOD_DELETE = 'DELETE';
+org_apache_flex_net_BinaryUploader.HTTP_METHOD_DELETE = 'DELETE';
 
 
 /**
  * @expose
  * @return {string} value The data.
  */
-org.apache.flex.net.BinaryUploader.prototype.get_data = function() {
+org_apache_flex_net_BinaryUploader.prototype.get_data = function() {
   return this.element.responseText;
 };
 
 
 /**
  * @expose
- * @return {org.apache.flex.utils.BinaryData} value The binary Data.
+ * @return {org_apache_flex_utils_BinaryData} value The binary Data.
  */
-org.apache.flex.net.BinaryUploader.prototype.get_binaryData = function() {
+org_apache_flex_net_BinaryUploader.prototype.get_binaryData = function() {
   return this.binaryData_;
 };
 
 
 /**
  * @expose
- * @param {org.apache.flex.utils.BinaryData} value The binary Data.
+ * @param {org_apache_flex_utils_BinaryData} value The binary Data.
  */
-org.apache.flex.net.BinaryUploader.prototype.set_binaryData = function(value) {
+org_apache_flex_net_BinaryUploader.prototype.set_binaryData = function(value) {
   this.binaryData_ = value;
 };
 
@@ -160,7 +160,7 @@ org.apache.flex.net.BinaryUploader.prototype.set_binaryData = function(value) {
  * @expose
  * @return {string} value The contentType.
  */
-org.apache.flex.net.BinaryUploader.prototype.get_contentType = function() {
+org_apache_flex_net_BinaryUploader.prototype.get_contentType = function() {
   return this.contentType_;
 };
 
@@ -169,7 +169,7 @@ org.apache.flex.net.BinaryUploader.prototype.get_contentType = function() {
  * @expose
  * @param {string} value The contentType.
  */
-org.apache.flex.net.BinaryUploader.prototype.set_contentType = function(value) {
+org_apache_flex_net_BinaryUploader.prototype.set_contentType = function(value) {
   this.contentType_ = value;
 };
 
@@ -178,7 +178,7 @@ org.apache.flex.net.BinaryUploader.prototype.set_contentType = function(value) {
  * @expose
  * @return {Array} value The array of HTTPHeaders.
  */
-org.apache.flex.net.BinaryUploader.prototype.get_headers = function() {
+org_apache_flex_net_BinaryUploader.prototype.get_headers = function() {
   if (this.headers_ === 'undefined') {
     this.headers_ = [];
   }
@@ -191,7 +191,7 @@ org.apache.flex.net.BinaryUploader.prototype.get_headers = function() {
  * @expose
  * @param {Array} value The array of HTTPHeaders.
  */
-org.apache.flex.net.BinaryUploader.prototype.set_headers = function(value) {
+org_apache_flex_net_BinaryUploader.prototype.set_headers = function(value) {
   this.headers_ = value;
 };
 
@@ -200,7 +200,7 @@ org.apache.flex.net.BinaryUploader.prototype.set_headers = function(value) {
  * @expose
  * @return {string} value The method.
  */
-org.apache.flex.net.BinaryUploader.prototype.get_method = function() {
+org_apache_flex_net_BinaryUploader.prototype.get_method = function() {
   return this.method_;
 };
 
@@ -209,7 +209,7 @@ org.apache.flex.net.BinaryUploader.prototype.get_method = function() {
  * @expose
  * @param {string} value The method.
  */
-org.apache.flex.net.BinaryUploader.prototype.set_method = function(value) {
+org_apache_flex_net_BinaryUploader.prototype.set_method = function(value) {
   this.method_ = value;
 };
 
@@ -218,7 +218,7 @@ org.apache.flex.net.BinaryUploader.prototype.set_method = function(value) {
  * @expose
  * @return {Array} value The array of HTTPHeaders.
  */
-org.apache.flex.net.BinaryUploader.prototype.get_responseHeaders = function() {
+org_apache_flex_net_BinaryUploader.prototype.get_responseHeaders = function() {
   var allHeaders, c, hdr, i, n, part1, part2;
 
   if (typeof this.responseHeaders_ === 'undefined') {
@@ -231,7 +231,7 @@ org.apache.flex.net.BinaryUploader.prototype.get_responseHeaders = function() {
       part1 = hdr.substring(0, c);
       part2 = hdr.substring(c + 2);
       this.responseHeaders_[i] =
-          new org.apache.flex.net.HTTPHeader(part1, part2);
+          new org_apache_flex_net_HTTPHeader(part1, part2);
     }
   }
   return this.responseHeaders_;
@@ -242,7 +242,7 @@ org.apache.flex.net.BinaryUploader.prototype.get_responseHeaders = function() {
  * @expose
  * @return {string} value The url.
  */
-org.apache.flex.net.BinaryUploader.prototype.get_responseURL = function() {
+org_apache_flex_net_BinaryUploader.prototype.get_responseURL = function() {
   return this.responseURL_;
 };
 
@@ -251,7 +251,7 @@ org.apache.flex.net.BinaryUploader.prototype.get_responseURL = function() {
  * @expose
  * @return {Number} value The status.
  */
-org.apache.flex.net.BinaryUploader.prototype.get_status = function() {
+org_apache_flex_net_BinaryUploader.prototype.get_status = function() {
   return this.status_;
 };
 
@@ -260,7 +260,7 @@ org.apache.flex.net.BinaryUploader.prototype.get_status = function() {
  * @expose
  * @return {Number} value The timeout.
  */
-org.apache.flex.net.BinaryUploader.prototype.get_timeout = function() {
+org_apache_flex_net_BinaryUploader.prototype.get_timeout = function() {
   return this.timeout_;
 };
 
@@ -269,7 +269,7 @@ org.apache.flex.net.BinaryUploader.prototype.get_timeout = function() {
  * @expose
  * @param {Number} value The timeout.
  */
-org.apache.flex.net.BinaryUploader.prototype.set_timeout = function(value) {
+org_apache_flex_net_BinaryUploader.prototype.set_timeout = function(value) {
   this.timeout_ = value;
 };
 
@@ -278,7 +278,7 @@ org.apache.flex.net.BinaryUploader.prototype.set_timeout = function(value) {
  * @expose
  * @return {string} value The url.
  */
-org.apache.flex.net.BinaryUploader.prototype.get_url = function() {
+org_apache_flex_net_BinaryUploader.prototype.get_url = function() {
   return this.url_;
 };
 
@@ -287,7 +287,7 @@ org.apache.flex.net.BinaryUploader.prototype.get_url = function() {
  * @expose
  * @param {string} value The url to fetch.
  */
-org.apache.flex.net.BinaryUploader.prototype.set_url = function(value) {
+org_apache_flex_net_BinaryUploader.prototype.set_url = function(value) {
   this.url_ = value;
 };
 
@@ -295,7 +295,7 @@ org.apache.flex.net.BinaryUploader.prototype.set_url = function(value) {
 /**
  * @expose
  */
-org.apache.flex.net.BinaryUploader.prototype.send = function() {
+org_apache_flex_net_BinaryUploader.prototype.send = function() {
   var binaryData, header, i, n, sawContentType, url;
 
   this.element.onreadystatechange = goog.bind(this.progressHandler, this);
@@ -304,7 +304,7 @@ org.apache.flex.net.BinaryUploader.prototype.send = function() {
 
   binaryData = null;
   if (this.binaryData_ !== undefined) {
-    if (this.method_ === org.apache.flex.net.BinaryUploader.HTTP_METHOD_GET) {
+    if (this.method_ === org_apache_flex_net_BinaryUploader.HTTP_METHOD_GET) {
       if (url.indexOf('?') !== -1) {
         url += this.binaryData_.get_data();
       } else {
@@ -323,7 +323,7 @@ org.apache.flex.net.BinaryUploader.prototype.send = function() {
     n = this.headers_.length;
     for (i = 0; i < n; i++) {
       header = this.headers_[i];
-      if (header.name === org.apache.flex.net.HTTPHeader.CONTENT_TYPE) {
+      if (header.name === org_apache_flex_net_HTTPHeader.CONTENT_TYPE) {
         sawContentType = true;
       }
 
@@ -331,10 +331,10 @@ org.apache.flex.net.BinaryUploader.prototype.send = function() {
     }
   }
 
-  if (this.method_ !== org.apache.flex.net.BinaryUploader.HTTP_METHOD_GET &&
+  if (this.method_ !== org_apache_flex_net_BinaryUploader.HTTP_METHOD_GET &&
       !sawContentType && binaryData) {
     this.element.setRequestHeader(
-        org.apache.flex.net.HTTPHeader.CONTENT_TYPE, this.binaryType_);
+        org_apache_flex_net_HTTPHeader.CONTENT_TYPE, this.binaryType_);
   }
 
   if (binaryData) {
@@ -350,7 +350,7 @@ org.apache.flex.net.BinaryUploader.prototype.send = function() {
 /**
  * @protected
  */
-org.apache.flex.net.BinaryUploader.prototype.progressHandler = function() {
+org_apache_flex_net_BinaryUploader.prototype.progressHandler = function() {
   if (this.element.readyState === 2) {
     this.status_ = this.element.status;
     this.dispatchEvent('httpResponseStatus');
@@ -365,14 +365,14 @@ org.apache.flex.net.BinaryUploader.prototype.progressHandler = function() {
  * @expose
  * @type {string}
  */
-org.apache.flex.net.BinaryUploader.prototype.id = null;
+org_apache_flex_net_BinaryUploader.prototype.id = null;
 
 
 /**
  * @expose
  * @return {string} The id.
  */
-org.apache.flex.net.BinaryUploader.prototype.get_id = function() {
+org_apache_flex_net_BinaryUploader.prototype.get_id = function() {
   return this.id;
 };
 
@@ -381,7 +381,7 @@ org.apache.flex.net.BinaryUploader.prototype.get_id = function() {
  * @expose
  * @param {Object} value The new id.
  */
-org.apache.flex.net.BinaryUploader.prototype.set_id = function(value) {
+org_apache_flex_net_BinaryUploader.prototype.set_id = function(value) {
   if (this.id !== value) {
     this.id = value;
     this.dispatchEvent('idChanged');
@@ -393,7 +393,7 @@ org.apache.flex.net.BinaryUploader.prototype.set_id = function(value) {
  * @expose
  * @return {Array} The array of descriptors.
  */
-org.apache.flex.net.BinaryUploader.prototype.get_MXMLDescriptor = function() {
+org_apache_flex_net_BinaryUploader.prototype.get_MXMLDescriptor = function() {
   return null;
 };
 
@@ -402,7 +402,7 @@ org.apache.flex.net.BinaryUploader.prototype.get_MXMLDescriptor = function() {
  * @expose
  * @return {Array} The array of properties.
  */
-org.apache.flex.net.BinaryUploader.prototype.get_MXMLProperties = function() {
+org_apache_flex_net_BinaryUploader.prototype.get_MXMLProperties = function() {
   return null;
 };
 
@@ -411,7 +411,7 @@ org.apache.flex.net.BinaryUploader.prototype.get_MXMLProperties = function() {
  * @param {Object} document The MXML object.
  * @param {string} id The id for the instance.
  */
-org.apache.flex.net.BinaryUploader.prototype.setDocument =
+org_apache_flex_net_BinaryUploader.prototype.setDocument =
     function(document, id) {
   this.document = document;
 };

http://git-wip-us.apache.org/repos/asf/flex-asjs/blob/49f207c4/frameworks/js/FlexJS/src/org/apache/flex/net/HTTPHeader.js
----------------------------------------------------------------------
diff --git a/frameworks/js/FlexJS/src/org/apache/flex/net/HTTPHeader.js b/frameworks/js/FlexJS/src/org/apache/flex/net/HTTPHeader.js
index c24420d..8eee6f2 100644
--- a/frameworks/js/FlexJS/src/org/apache/flex/net/HTTPHeader.js
+++ b/frameworks/js/FlexJS/src/org/apache/flex/net/HTTPHeader.js
@@ -12,7 +12,7 @@
  * limitations under the License.
  */
 
-goog.provide('org.apache.flex.net.HTTPHeader');
+goog.provide('org_apache_flex_net_HTTPHeader');
 
 
 
@@ -21,7 +21,7 @@ goog.provide('org.apache.flex.net.HTTPHeader');
  * @param {string=} opt_name The name.
  * @param {string=} opt_value The value.
  */
-org.apache.flex.net.HTTPHeader = function(opt_name, opt_value) {
+org_apache_flex_net_HTTPHeader = function(opt_name, opt_value) {
   if (typeof opt_name !== 'undefined') {
     this.name = opt_name;
   }
@@ -37,27 +37,27 @@ org.apache.flex.net.HTTPHeader = function(opt_name, opt_value) {
  *
  * @type {Object.<string, Array.<Object>>}
  */
-org.apache.flex.net.HTTPHeader.prototype.FLEXJS_CLASS_INFO =
+org_apache_flex_net_HTTPHeader.prototype.FLEXJS_CLASS_INFO =
     { names: [{ name: 'HTTPHeader',
-                qName: 'org.apache.flex.net.HTTPHeader'}] };
+                qName: 'org_apache_flex_net_HTTPHeader'}] };
 
 
 /**
  * @expose
  * @type {string}
  */
-org.apache.flex.net.HTTPHeader.CONTENT_TYPE = 'Content-type';
+org_apache_flex_net_HTTPHeader.CONTENT_TYPE = 'Content-type';
 
 
 /**
  * @expose
  * @type {?string}
  */
-org.apache.flex.net.HTTPHeader.prototype.value = null;
+org_apache_flex_net_HTTPHeader.prototype.value = null;
 
 
 /**
  * @expose
  * @type {?string}
  */
-org.apache.flex.net.HTTPHeader.prototype.name = null;
+org_apache_flex_net_HTTPHeader.prototype.name = null;

http://git-wip-us.apache.org/repos/asf/flex-asjs/blob/49f207c4/frameworks/js/FlexJS/src/org/apache/flex/net/HTTPService.js
----------------------------------------------------------------------
diff --git a/frameworks/js/FlexJS/src/org/apache/flex/net/HTTPService.js b/frameworks/js/FlexJS/src/org/apache/flex/net/HTTPService.js
index eaf5448..acefa66 100644
--- a/frameworks/js/FlexJS/src/org/apache/flex/net/HTTPService.js
+++ b/frameworks/js/FlexJS/src/org/apache/flex/net/HTTPService.js
@@ -12,19 +12,19 @@
  * limitations under the License.
  */
 
-goog.provide('org.apache.flex.net.HTTPService');
+goog.provide('org_apache_flex_net_HTTPService');
 
-goog.require('org.apache.flex.core.HTMLElementWrapper');
-goog.require('org.apache.flex.net.HTTPHeader');
+goog.require('org_apache_flex_core_HTMLElementWrapper');
+goog.require('org_apache_flex_net_HTTPHeader');
 
 
 
 /**
  * @constructor
- * @extends {org.apache.flex.core.HTMLElementWrapper}
+ * @extends {org_apache_flex_core_HTMLElementWrapper}
  */
-org.apache.flex.net.HTTPService = function() {
-  org.apache.flex.net.HTTPService.base(this, 'constructor');
+org_apache_flex_net_HTTPService = function() {
+  org_apache_flex_net_HTTPService.base(this, 'constructor');
 
   /**
    * @private
@@ -93,8 +93,8 @@ org.apache.flex.net.HTTPService = function() {
 
   this.element = new XMLHttpRequest();
 };
-goog.inherits(org.apache.flex.net.HTTPService,
-    org.apache.flex.core.HTMLElementWrapper);
+goog.inherits(org_apache_flex_net_HTTPService,
+    org_apache_flex_core_HTMLElementWrapper);
 
 
 /**
@@ -102,44 +102,44 @@ goog.inherits(org.apache.flex.net.HTTPService,
  *
  * @type {Object.<string, Array.<Object>>}
  */
-org.apache.flex.net.HTTPService.prototype.FLEXJS_CLASS_INFO =
+org_apache_flex_net_HTTPService.prototype.FLEXJS_CLASS_INFO =
     { names: [{ name: 'HTTPService',
-                qName: 'org.apache.flex.net.HTTPService'}] };
+                qName: 'org_apache_flex_net_HTTPService'}] };
 
 
 /**
  * @expose
  * @type {string}
  */
-org.apache.flex.net.HTTPService.HTTP_METHOD_GET = 'GET';
+org_apache_flex_net_HTTPService.HTTP_METHOD_GET = 'GET';
 
 
 /**
  * @expose
  * @type {string}
  */
-org.apache.flex.net.HTTPService.HTTP_METHOD_POST = 'POST';
+org_apache_flex_net_HTTPService.HTTP_METHOD_POST = 'POST';
 
 
 /**
  * @expose
  * @type {string}
  */
-org.apache.flex.net.HTTPService.HTTP_METHOD_PUT = 'PUT';
+org_apache_flex_net_HTTPService.HTTP_METHOD_PUT = 'PUT';
 
 
 /**
  * @expose
  * @type {string}
  */
-org.apache.flex.net.HTTPService.HTTP_METHOD_DELETE = 'DELETE';
+org_apache_flex_net_HTTPService.HTTP_METHOD_DELETE = 'DELETE';
 
 
 /**
  * @expose
  * @param {Array.<Object>} value The array of beads.
  */
-org.apache.flex.net.HTTPService.prototype.set_beads = function(value) {
+org_apache_flex_net_HTTPService.prototype.set_beads = function(value) {
   this.beads_ = value;
 };
 
@@ -148,7 +148,7 @@ org.apache.flex.net.HTTPService.prototype.set_beads = function(value) {
  * @expose
  * @return {string} value The data.
  */
-org.apache.flex.net.HTTPService.prototype.get_data = function() {
+org_apache_flex_net_HTTPService.prototype.get_data = function() {
   return this.element.responseText;
 };
 
@@ -157,7 +157,7 @@ org.apache.flex.net.HTTPService.prototype.get_data = function() {
  * @expose
  * @return {?string} value The contentData.
  */
-org.apache.flex.net.HTTPService.prototype.get_contentData = function() {
+org_apache_flex_net_HTTPService.prototype.get_contentData = function() {
   return this.contentData_;
 };
 
@@ -166,7 +166,7 @@ org.apache.flex.net.HTTPService.prototype.get_contentData = function() {
  * @expose
  * @param {string} value The contentData.
  */
-org.apache.flex.net.HTTPService.prototype.set_contentData = function(value) {
+org_apache_flex_net_HTTPService.prototype.set_contentData = function(value) {
   this.contentData_ = value;
 };
 
@@ -175,7 +175,7 @@ org.apache.flex.net.HTTPService.prototype.set_contentData = function(value) {
  * @expose
  * @return {string} value The contentType.
  */
-org.apache.flex.net.HTTPService.prototype.get_contentType = function() {
+org_apache_flex_net_HTTPService.prototype.get_contentType = function() {
   return this.contentType_;
 };
 
@@ -184,7 +184,7 @@ org.apache.flex.net.HTTPService.prototype.get_contentType = function() {
  * @expose
  * @param {string} value The contentType.
  */
-org.apache.flex.net.HTTPService.prototype.set_contentType = function(value) {
+org_apache_flex_net_HTTPService.prototype.set_contentType = function(value) {
   this.contentType_ = value;
 };
 
@@ -193,7 +193,7 @@ org.apache.flex.net.HTTPService.prototype.set_contentType = function(value) {
  * @expose
  * @return {Array} value The array of HTTPHeaders.
  */
-org.apache.flex.net.HTTPService.prototype.get_headers = function() {
+org_apache_flex_net_HTTPService.prototype.get_headers = function() {
   if (this.headers_ === undefined) {
     this.headers_ = [];
   }
@@ -206,7 +206,7 @@ org.apache.flex.net.HTTPService.prototype.get_headers = function() {
  * @expose
  * @param {Array} value The array of HTTPHeaders.
  */
-org.apache.flex.net.HTTPService.prototype.set_headers = function(value) {
+org_apache_flex_net_HTTPService.prototype.set_headers = function(value) {
   this.headers_ = value;
 };
 
@@ -215,7 +215,7 @@ org.apache.flex.net.HTTPService.prototype.set_headers = function(value) {
  * @expose
  * @return {string} value The method.
  */
-org.apache.flex.net.HTTPService.prototype.get_method = function() {
+org_apache_flex_net_HTTPService.prototype.get_method = function() {
   return this.method_;
 };
 
@@ -224,7 +224,7 @@ org.apache.flex.net.HTTPService.prototype.get_method = function() {
  * @expose
  * @param {string} value The method.
  */
-org.apache.flex.net.HTTPService.prototype.set_method = function(value) {
+org_apache_flex_net_HTTPService.prototype.set_method = function(value) {
   this.method_ = value;
 };
 
@@ -233,7 +233,7 @@ org.apache.flex.net.HTTPService.prototype.set_method = function(value) {
  * @expose
  * @return {Array} value The array of HTTPHeaders.
  */
-org.apache.flex.net.HTTPService.prototype.get_responseHeaders = function() {
+org_apache_flex_net_HTTPService.prototype.get_responseHeaders = function() {
   var allHeaders, c, hdr, i, n, part1, part2;
 
   if (typeof this.responseHeaders_ === 'undefined') {
@@ -246,7 +246,7 @@ org.apache.flex.net.HTTPService.prototype.get_responseHeaders = function() {
       part1 = hdr.substring(0, c);
       part2 = hdr.substring(c + 2);
       this.responseHeaders_[i] =
-          new org.apache.flex.net.HTTPHeader(part1, part2);
+          new org_apache_flex_net_HTTPHeader(part1, part2);
     }
   }
   return this.responseHeaders_;
@@ -257,7 +257,7 @@ org.apache.flex.net.HTTPService.prototype.get_responseHeaders = function() {
  * @expose
  * @return {?string} value The url.
  */
-org.apache.flex.net.HTTPService.prototype.get_responseURL = function() {
+org_apache_flex_net_HTTPService.prototype.get_responseURL = function() {
   return this.responseURL_;
 };
 
@@ -266,7 +266,7 @@ org.apache.flex.net.HTTPService.prototype.get_responseURL = function() {
  * @expose
  * @return {number} value The status.
  */
-org.apache.flex.net.HTTPService.prototype.get_status = function() {
+org_apache_flex_net_HTTPService.prototype.get_status = function() {
   return this.status_;
 };
 
@@ -275,7 +275,7 @@ org.apache.flex.net.HTTPService.prototype.get_status = function() {
  * @expose
  * @return {number} value The timeout.
  */
-org.apache.flex.net.HTTPService.prototype.get_timeout = function() {
+org_apache_flex_net_HTTPService.prototype.get_timeout = function() {
   return this.timeout_;
 };
 
@@ -284,7 +284,7 @@ org.apache.flex.net.HTTPService.prototype.get_timeout = function() {
  * @expose
  * @param {number} value The timeout.
  */
-org.apache.flex.net.HTTPService.prototype.set_timeout = function(value) {
+org_apache_flex_net_HTTPService.prototype.set_timeout = function(value) {
   this.timeout_ = value;
 };
 
@@ -293,7 +293,7 @@ org.apache.flex.net.HTTPService.prototype.set_timeout = function(value) {
  * @expose
  * @return {?string} value The url.
  */
-org.apache.flex.net.HTTPService.prototype.get_url = function() {
+org_apache_flex_net_HTTPService.prototype.get_url = function() {
   return this.url_;
 };
 
@@ -302,7 +302,7 @@ org.apache.flex.net.HTTPService.prototype.get_url = function() {
  * @expose
  * @param {string} value The url to fetch.
  */
-org.apache.flex.net.HTTPService.prototype.set_url = function(value) {
+org_apache_flex_net_HTTPService.prototype.set_url = function(value) {
   this.url_ = value;
 };
 
@@ -310,7 +310,7 @@ org.apache.flex.net.HTTPService.prototype.set_url = function(value) {
 /**
  * @expose
  */
-org.apache.flex.net.HTTPService.prototype.send = function() {
+org_apache_flex_net_HTTPService.prototype.send = function() {
   var contentData, header, i, n, sawContentType, url;
 
   if (this.strand == null && this.beads_) {
@@ -326,7 +326,7 @@ org.apache.flex.net.HTTPService.prototype.send = function() {
 
   contentData = null;
   if (this.contentData_ !== undefined) {
-    if (this.method_ === org.apache.flex.net.HTTPService.HTTP_METHOD_GET) {
+    if (this.method_ === org_apache_flex_net_HTTPService.HTTP_METHOD_GET) {
       if (url.indexOf('?') !== -1) {
         url += this.contentData_;
       } else {
@@ -345,7 +345,7 @@ org.apache.flex.net.HTTPService.prototype.send = function() {
     n = this.headers_.length;
     for (i = 0; i < n; i++) {
       header = this.headers_[i];
-      if (header.name === org.apache.flex.net.HTTPHeader.CONTENT_TYPE) {
+      if (header.name === org_apache_flex_net_HTTPHeader.CONTENT_TYPE) {
         sawContentType = true;
       }
 
@@ -353,10 +353,10 @@ org.apache.flex.net.HTTPService.prototype.send = function() {
     }
   }
 
-  if (this.method_ !== org.apache.flex.net.HTTPService.HTTP_METHOD_GET &&
+  if (this.method_ !== org_apache_flex_net_HTTPService.HTTP_METHOD_GET &&
       !sawContentType && contentData) {
     this.element.setRequestHeader(
-        org.apache.flex.net.HTTPHeader.CONTENT_TYPE, this.contentType_);
+        org_apache_flex_net_HTTPHeader.CONTENT_TYPE, this.contentType_);
   }
 
   if (contentData) {
@@ -372,7 +372,7 @@ org.apache.flex.net.HTTPService.prototype.send = function() {
 /**
  * @protected
  */
-org.apache.flex.net.HTTPService.prototype.progressHandler = function() {
+org_apache_flex_net_HTTPService.prototype.progressHandler = function() {
   if (this.element.readyState === 2) {
     this.status_ = this.element.status;
     this.dispatchEvent('httpResponseStatus');
@@ -387,14 +387,14 @@ org.apache.flex.net.HTTPService.prototype.progressHandler = function() {
  * @expose
  * @type {?string}
  */
-org.apache.flex.net.HTTPService.prototype.id = null;
+org_apache_flex_net_HTTPService.prototype.id = null;
 
 
 /**
  * @expose
  * @return {?string} The id.
  */
-org.apache.flex.net.HTTPService.prototype.get_id = function() {
+org_apache_flex_net_HTTPService.prototype.get_id = function() {
   return this.id;
 };
 
@@ -403,7 +403,7 @@ org.apache.flex.net.HTTPService.prototype.get_id = function() {
  * @expose
  * @param {string} value The new id.
  */
-org.apache.flex.net.HTTPService.prototype.set_id = function(value) {
+org_apache_flex_net_HTTPService.prototype.set_id = function(value) {
   if (this.id !== value) {
     this.id = value;
     this.dispatchEvent('idChanged');
@@ -415,7 +415,7 @@ org.apache.flex.net.HTTPService.prototype.set_id = function(value) {
  * @expose
  * @return {Array} The array of descriptors.
  */
-org.apache.flex.net.HTTPService.prototype.get_MXMLDescriptor = function() {
+org_apache_flex_net_HTTPService.prototype.get_MXMLDescriptor = function() {
   return null;
 };
 
@@ -424,7 +424,7 @@ org.apache.flex.net.HTTPService.prototype.get_MXMLDescriptor = function() {
  * @expose
  * @return {Array} The array of properties.
  */
-org.apache.flex.net.HTTPService.prototype.get_MXMLProperties = function() {
+org_apache_flex_net_HTTPService.prototype.get_MXMLProperties = function() {
   return null;
 };
 
@@ -433,7 +433,7 @@ org.apache.flex.net.HTTPService.prototype.get_MXMLProperties = function() {
  * @param {Object} document The MXML object.
  * @param {string} id The id for the instance.
  */
-org.apache.flex.net.HTTPService.prototype.setDocument = function(document, id) {
+org_apache_flex_net_HTTPService.prototype.setDocument = function(document, id) {
   this.document = document;
 };
 
@@ -442,7 +442,7 @@ org.apache.flex.net.HTTPService.prototype.setDocument = function(document, id) {
  * @expose
  * @param {Object} value The strand.
  */
-org.apache.flex.net.HTTPService.prototype.set_strand = function(value) {
+org_apache_flex_net_HTTPService.prototype.set_strand = function(value) {
   if (this.strand_ !== value) {
     this.strand_ = value;
   }

http://git-wip-us.apache.org/repos/asf/flex-asjs/blob/49f207c4/frameworks/js/FlexJS/src/org/apache/flex/net/JSONInputParser.js
----------------------------------------------------------------------
diff --git a/frameworks/js/FlexJS/src/org/apache/flex/net/JSONInputParser.js b/frameworks/js/FlexJS/src/org/apache/flex/net/JSONInputParser.js
index e03201c..83a41d1 100644
--- a/frameworks/js/FlexJS/src/org/apache/flex/net/JSONInputParser.js
+++ b/frameworks/js/FlexJS/src/org/apache/flex/net/JSONInputParser.js
@@ -12,14 +12,14 @@
  * limitations under the License.
  */
 
-goog.provide('org.apache.flex.net.JSONInputParser');
+goog.provide('org_apache_flex_net_JSONInputParser');
 
 
 
 /**
  * @constructor
  */
-org.apache.flex.net.JSONInputParser = function() {
+org_apache_flex_net_JSONInputParser = function() {
 };
 
 
@@ -28,9 +28,9 @@ org.apache.flex.net.JSONInputParser = function() {
  *
  * @type {Object.<string, Array.<Object>>}
  */
-org.apache.flex.net.JSONInputParser.prototype.FLEXJS_CLASS_INFO =
+org_apache_flex_net_JSONInputParser.prototype.FLEXJS_CLASS_INFO =
     { names: [{ name: 'JSONInputParser',
-                qName: 'org.apache.flex.net.JSONInputParser'}] };
+                qName: 'org_apache_flex_net_JSONInputParser'}] };
 
 
 /**
@@ -38,7 +38,7 @@ org.apache.flex.net.JSONInputParser.prototype.FLEXJS_CLASS_INFO =
  * @param {string} s The input string.
  * @return {Array.<string>} The Array of unparsed objects.
  */
-org.apache.flex.net.JSONInputParser.prototype.parseItems = function(s) {
+org_apache_flex_net_JSONInputParser.prototype.parseItems = function(s) {
   var c = s.indexOf('[');
   if (c != -1) {
     var c2 = s.lastIndexOf(']');

http://git-wip-us.apache.org/repos/asf/flex-asjs/blob/49f207c4/frameworks/js/FlexJS/src/org/apache/flex/net/JSONItemConverter.js
----------------------------------------------------------------------
diff --git a/frameworks/js/FlexJS/src/org/apache/flex/net/JSONItemConverter.js b/frameworks/js/FlexJS/src/org/apache/flex/net/JSONItemConverter.js
index d405d0a..698b514 100644
--- a/frameworks/js/FlexJS/src/org/apache/flex/net/JSONItemConverter.js
+++ b/frameworks/js/FlexJS/src/org/apache/flex/net/JSONItemConverter.js
@@ -12,14 +12,14 @@
  * limitations under the License.
  */
 
-goog.provide('org.apache.flex.net.JSONItemConverter');
+goog.provide('org_apache_flex_net_JSONItemConverter');
 
 
 
 /**
  * @constructor
  */
-org.apache.flex.net.JSONItemConverter = function() {
+org_apache_flex_net_JSONItemConverter = function() {
 };
 
 
@@ -28,9 +28,9 @@ org.apache.flex.net.JSONItemConverter = function() {
  *
  * @type {Object.<string, Array.<Object>>}
  */
-org.apache.flex.net.JSONItemConverter.prototype.FLEXJS_CLASS_INFO =
+org_apache_flex_net_JSONItemConverter.prototype.FLEXJS_CLASS_INFO =
     { names: [{ name: 'JSONItemConverter',
-                qName: 'org.apache.flex.net.JSONItemConverter'}] };
+                qName: 'org_apache_flex_net_JSONItemConverter'}] };
 
 
 /**
@@ -38,7 +38,7 @@ org.apache.flex.net.JSONItemConverter.prototype.FLEXJS_CLASS_INFO =
  * @param {string} s The input string.
  * @return {*} The object.
  */
-org.apache.flex.net.JSONItemConverter.prototype.convertItem = function(s) {
+org_apache_flex_net_JSONItemConverter.prototype.convertItem = function(s) {
   var c = s.indexOf('{)');
   if (c > 0)
     s = s.substring(c);
@@ -54,7 +54,7 @@ org.apache.flex.net.JSONItemConverter.prototype.convertItem = function(s) {
  * @param {string} propName The name of the property.
  * @return {Object} value The value of the property.
  */
-org.apache.flex.net.JSONItemConverter.prototype.getProperty =
+org_apache_flex_net_JSONItemConverter.prototype.getProperty =
     function(obj, propName) {
   if (typeof obj['get_' + propName] === 'function') {
     return obj['get_' + propName]();
@@ -69,7 +69,7 @@ org.apache.flex.net.JSONItemConverter.prototype.getProperty =
  * @param {string} propName The name of the property.
  * @param {Object} value The value of the property.
  */
-org.apache.flex.net.JSONItemConverter.prototype.setProperty =
+org_apache_flex_net_JSONItemConverter.prototype.setProperty =
 function(obj, propName, value) {
   if (typeof obj['set_' + propName] === 'function') {
     obj['set_' + propName](value);

http://git-wip-us.apache.org/repos/asf/flex-asjs/blob/49f207c4/frameworks/js/FlexJS/src/org/apache/flex/net/dataConverters/LazyCollection.js
----------------------------------------------------------------------
diff --git a/frameworks/js/FlexJS/src/org/apache/flex/net/dataConverters/LazyCollection.js b/frameworks/js/FlexJS/src/org/apache/flex/net/dataConverters/LazyCollection.js
index 5330ce1..bd3db2a 100644
--- a/frameworks/js/FlexJS/src/org/apache/flex/net/dataConverters/LazyCollection.js
+++ b/frameworks/js/FlexJS/src/org/apache/flex/net/dataConverters/LazyCollection.js
@@ -12,18 +12,19 @@
  * limitations under the License.
  */
 
-goog.provide('org.apache.flex.net.dataConverters.LazyCollection');
+goog.provide('org_apache_flex_net_dataConverters_LazyCollection');
 
-goog.require('org.apache.flex.events.EventDispatcher');
-goog.require('org.apache.flex.events.IEventDispatcher');
+goog.require('org_apache_flex_events_EventDispatcher');
+goog.require('org_apache_flex_events_IEventDispatcher');
 
 
 
 /**
  * @constructor
+ * @extends {org_apache_flex_events_EventDispatcher}
  */
-org.apache.flex.net.dataConverters.LazyCollection = function() {
-  org.apache.flex.net.dataConverters.LazyCollection.base(this, 'constructor');
+org_apache_flex_net_dataConverters_LazyCollection = function() {
+  org_apache_flex_net_dataConverters_LazyCollection.base(this, 'constructor');
   /**
    * @private
    * @type {Object}
@@ -55,7 +56,7 @@ org.apache.flex.net.dataConverters.LazyCollection = function() {
    */
   this.strand_ = null;
 };
-goog.inherits(org.apache.flex.net.dataConverters.LazyCollection, org.apache.flex.events.EventDispatcher);
+goog.inherits(org_apache_flex_net_dataConverters_LazyCollection, org_apache_flex_events_EventDispatcher);
 
 
 /**
@@ -63,17 +64,17 @@ goog.inherits(org.apache.flex.net.dataConverters.LazyCollection, org.apache.flex
  *
  * @type {Object.<string, Array.<Object>>}
  */
-org.apache.flex.net.dataConverters.LazyCollection.prototype.FLEXJS_CLASS_INFO =
+org_apache_flex_net_dataConverters_LazyCollection.prototype.FLEXJS_CLASS_INFO =
     { names: [{ name: 'LazyCollection',
-                qName: 'org.apache.flex.net.dataConverters.LazyCollection'}],
-      interfaces: [org.apache.flex.events.IEventDispatcher]};
+                qName: 'org_apache_flex_net_dataConverters_LazyCollection'}],
+      interfaces: [org_apache_flex_events_IEventDispatcher]};
 
 
 /**
  * @expose
  * @return {Object} value The input parser.
  */
-org.apache.flex.net.dataConverters.LazyCollection.prototype.get_inputParser =
+org_apache_flex_net_dataConverters_LazyCollection.prototype.get_inputParser =
     function() {
   return this.inputParser_;
 };
@@ -83,7 +84,7 @@ org.apache.flex.net.dataConverters.LazyCollection.prototype.get_inputParser =
  * @expose
  * @param {Object} value The input parser.
  */
-org.apache.flex.net.dataConverters.LazyCollection.prototype.set_inputParser =
+org_apache_flex_net_dataConverters_LazyCollection.prototype.set_inputParser =
     function(value) {
   this.inputParser_ = value;
 };
@@ -93,7 +94,7 @@ org.apache.flex.net.dataConverters.LazyCollection.prototype.set_inputParser =
  * @expose
  * @return {Object} value The input parser.
  */
-org.apache.flex.net.dataConverters.LazyCollection.prototype.get_itemConverter =
+org_apache_flex_net_dataConverters_LazyCollection.prototype.get_itemConverter =
     function() {
   return this.itemConverter_;
 };
@@ -103,7 +104,7 @@ org.apache.flex.net.dataConverters.LazyCollection.prototype.get_itemConverter =
  * @expose
  * @param {Object} value The input parser.
  */
-org.apache.flex.net.dataConverters.LazyCollection.prototype.set_itemConverter =
+org_apache_flex_net_dataConverters_LazyCollection.prototype.set_itemConverter =
     function(value) {
   this.itemConverter_ = value;
 };
@@ -113,14 +114,14 @@ org.apache.flex.net.dataConverters.LazyCollection.prototype.set_itemConverter =
  * @expose
  * @type {string}
  */
-org.apache.flex.net.dataConverters.LazyCollection.prototype.id = '';
+org_apache_flex_net_dataConverters_LazyCollection.prototype.id = '';
 
 
 /**
  * @expose
  * @return {string} The id.
  */
-org.apache.flex.net.dataConverters.LazyCollection.prototype.get_id =
+org_apache_flex_net_dataConverters_LazyCollection.prototype.get_id =
     function() {
   return this.id;
 };
@@ -130,7 +131,7 @@ org.apache.flex.net.dataConverters.LazyCollection.prototype.get_id =
  * @expose
  * @param {string} value The new id.
  */
-org.apache.flex.net.dataConverters.LazyCollection.prototype.set_id =
+org_apache_flex_net_dataConverters_LazyCollection.prototype.set_id =
     function(value) {
   if (this.id !== value) {
     this.id = value;
@@ -143,7 +144,7 @@ org.apache.flex.net.dataConverters.LazyCollection.prototype.set_id =
  * @expose
  * @param {Object} value The new host.
  */
-org.apache.flex.net.dataConverters.LazyCollection.prototype.set_strand =
+org_apache_flex_net_dataConverters_LazyCollection.prototype.set_strand =
     function(value) {
   if (this.strand_ !== value) {
     this.strand_ = value;
@@ -156,7 +157,7 @@ org.apache.flex.net.dataConverters.LazyCollection.prototype.set_strand =
 /**
  * @protected
  */
-org.apache.flex.net.dataConverters.LazyCollection.prototype.completeHandler =
+org_apache_flex_net_dataConverters_LazyCollection.prototype.completeHandler =
     function() {
   var results = this.strand_.get_data();
   this.rawData_ = this.inputParser_.parseItems(results);
@@ -170,7 +171,7 @@ org.apache.flex.net.dataConverters.LazyCollection.prototype.completeHandler =
  * @param {number} index The index in the collection.
  * @return {Object} An item in the collection.
  */
-org.apache.flex.net.dataConverters.LazyCollection.prototype.getItemAt =
+org_apache_flex_net_dataConverters_LazyCollection.prototype.getItemAt =
     function(index) {
   if (this.data_[index] === undefined) {
     this.data_[index] =
@@ -185,7 +186,7 @@ org.apache.flex.net.dataConverters.LazyCollection.prototype.getItemAt =
  * @expose
  * @return {string} The number of items in the collection.
  */
-org.apache.flex.net.dataConverters.LazyCollection.prototype.get_length =
+org_apache_flex_net_dataConverters_LazyCollection.prototype.get_length =
     function() {
   return this.rawData_ ? this.rawData_.length : 0;
 };

http://git-wip-us.apache.org/repos/asf/flex-asjs/blob/49f207c4/frameworks/js/FlexJS/src/org/apache/flex/svg/TextButton.js
----------------------------------------------------------------------
diff --git a/frameworks/js/FlexJS/src/org/apache/flex/svg/TextButton.js b/frameworks/js/FlexJS/src/org/apache/flex/svg/TextButton.js
index 56206ba..1300f5f 100644
--- a/frameworks/js/FlexJS/src/org/apache/flex/svg/TextButton.js
+++ b/frameworks/js/FlexJS/src/org/apache/flex/svg/TextButton.js
@@ -12,21 +12,21 @@
  * limitations under the License.
  */
 
-goog.provide('org.apache.flex.svg.TextButton');
+goog.provide('org_apache_flex_svg_TextButton');
 
-goog.require('org.apache.flex.core.UIBase');
+goog.require('org_apache_flex_core_UIBase');
 
 
 
 /**
  * @constructor
- * @extends {org.apache.flex.core.UIBase}
+ * @extends {org_apache_flex_core_UIBase}
  */
-org.apache.flex.svg.TextButton = function() {
-  org.apache.flex.svg.TextButton.base(this, 'constructor');
+org_apache_flex_svg_TextButton = function() {
+  org_apache_flex_svg_TextButton.base(this, 'constructor');
 };
-goog.inherits(org.apache.flex.svg.TextButton,
-    org.apache.flex.core.UIBase);
+goog.inherits(org_apache_flex_svg_TextButton,
+    org_apache_flex_core_UIBase);
 
 
 /**
@@ -34,15 +34,15 @@ goog.inherits(org.apache.flex.svg.TextButton,
  *
  * @type {Object.<string, Array.<Object>>}
  */
-org.apache.flex.svg.TextButton.prototype.FLEXJS_CLASS_INFO =
+org_apache_flex_svg_TextButton.prototype.FLEXJS_CLASS_INFO =
     { names: [{ name: 'TextButton',
-                qName: 'org.apache.flex.svg.TextButton'}] };
+                qName: 'org_apache_flex_svg_TextButton'}] };
 
 
 /**
  * @override
  */
-org.apache.flex.svg.TextButton.prototype.createElement =
+org_apache_flex_svg_TextButton.prototype.createElement =
     function() {
   this.element = document.createElement('embed');
   this.element.setAttribute('src', 'org/apache/flex/svg/assets/TextButton_Skin.svg');
@@ -56,7 +56,7 @@ org.apache.flex.svg.TextButton.prototype.createElement =
 /**
  * @override
  */
-org.apache.flex.svg.TextButton.prototype.finalizeElement =
+org_apache_flex_svg_TextButton.prototype.finalizeElement =
     function() {
   var listenersArray;
   if (goog.events.hasListener(this.element, goog.events.EventType.CLICK)) {
@@ -78,7 +78,7 @@ org.apache.flex.svg.TextButton.prototype.finalizeElement =
  * @expose
  * @return {string} The text getter.
  */
-org.apache.flex.svg.TextButton.prototype.get_text =
+org_apache_flex_svg_TextButton.prototype.get_text =
     function() {
   return this.element.getAttribute('label');
 };
@@ -88,7 +88,7 @@ org.apache.flex.svg.TextButton.prototype.get_text =
  * @expose
  * @param {string} value The text setter.
  */
-org.apache.flex.svg.TextButton.prototype.set_text =
+org_apache_flex_svg_TextButton.prototype.set_text =
     function(value) {
   this.element.setAttribute('label', value);
 };

http://git-wip-us.apache.org/repos/asf/flex-asjs/blob/49f207c4/frameworks/js/FlexJS/src/org/apache/flex/utils/BinaryData.js
----------------------------------------------------------------------
diff --git a/frameworks/js/FlexJS/src/org/apache/flex/utils/BinaryData.js b/frameworks/js/FlexJS/src/org/apache/flex/utils/BinaryData.js
index 10e04e9..0bf23b5 100644
--- a/frameworks/js/FlexJS/src/org/apache/flex/utils/BinaryData.js
+++ b/frameworks/js/FlexJS/src/org/apache/flex/utils/BinaryData.js
@@ -12,14 +12,14 @@
  * limitations under the License.
  */
 
-goog.provide('org.apache.flex.utils.BinaryData');
+goog.provide('org_apache_flex_utils_BinaryData');
 
 
 
 /**
  * @constructor
  */
-org.apache.flex.utils.BinaryData = function() {
+org_apache_flex_utils_BinaryData = function() {
 
   /**
    * @private
@@ -41,16 +41,16 @@ org.apache.flex.utils.BinaryData = function() {
  *
  * @type {Object.<string, Array.<Object>>}
  */
-org.apache.flex.utils.BinaryData.prototype.FLEXJS_CLASS_INFO =
+org_apache_flex_utils_BinaryData.prototype.FLEXJS_CLASS_INFO =
     { names: [{ name: 'BinaryData',
-                qName: 'org.apache.flex.utils.BinaryData'}] };
+                qName: 'org_apache_flex_utils_BinaryData'}] };
 
 
 /**
  * @expose
  * @return {Object} The platform-specific data.
  */
-org.apache.flex.utils.BinaryData.prototype.get_data = function() {
+org_apache_flex_utils_BinaryData.prototype.get_data = function() {
   return this.data_;
 };
 
@@ -59,7 +59,7 @@ org.apache.flex.utils.BinaryData.prototype.get_data = function() {
  * @expose
  * @param {number} b The byte to write.
  */
-org.apache.flex.utils.BinaryData.prototype.writeByte = function(b) {
+org_apache_flex_utils_BinaryData.prototype.writeByte = function(b) {
   var view;
 
   this.growBuffer(1);
@@ -74,7 +74,7 @@ org.apache.flex.utils.BinaryData.prototype.writeByte = function(b) {
  * @expose
  * @param {number} s The 16-bit integer to write.
  */
-org.apache.flex.utils.BinaryData.prototype.writeShort = function(s) {
+org_apache_flex_utils_BinaryData.prototype.writeShort = function(s) {
   var view;
 
   this.growBuffer(2);
@@ -89,7 +89,7 @@ org.apache.flex.utils.BinaryData.prototype.writeShort = function(s) {
  * @expose
  * @param {number} num The 32-bit integer to write.
  */
-org.apache.flex.utils.BinaryData.prototype.writeInt = function(num) {
+org_apache_flex_utils_BinaryData.prototype.writeInt = function(num) {
   var view;
 
   this.growBuffer(4);
@@ -104,7 +104,7 @@ org.apache.flex.utils.BinaryData.prototype.writeInt = function(num) {
  * @expose
  * @param {number} num The 32-bit unsigned integer to write.
  */
-org.apache.flex.utils.BinaryData.prototype.writeUnsignedInt =
+org_apache_flex_utils_BinaryData.prototype.writeUnsignedInt =
     function(num) {
   var view;
 
@@ -120,7 +120,7 @@ org.apache.flex.utils.BinaryData.prototype.writeUnsignedInt =
  * @expose
  * @return {number} The byte that was read.
  */
-org.apache.flex.utils.BinaryData.prototype.readByte = function() {
+org_apache_flex_utils_BinaryData.prototype.readByte = function() {
   var view;
 
   view = new Int8Array(this.data_, this.position_, 1);
@@ -133,7 +133,7 @@ org.apache.flex.utils.BinaryData.prototype.readByte = function() {
  * @expose
  * @return {number} The 16-bit integer that was read.
  */
-org.apache.flex.utils.BinaryData.prototype.readShort = function() {
+org_apache_flex_utils_BinaryData.prototype.readShort = function() {
   var view;
 
   view = new Int16Array(this.data_, this.position_, 1);
@@ -146,7 +146,7 @@ org.apache.flex.utils.BinaryData.prototype.readShort = function() {
  * @expose
  * @return {number} The 32-bit integer that was read.
  */
-org.apache.flex.utils.BinaryData.prototype.readInteger = function() {
+org_apache_flex_utils_BinaryData.prototype.readInteger = function() {
   var view;
 
   view = new Int32Array(this.data_, this.position_, 1);
@@ -159,7 +159,7 @@ org.apache.flex.utils.BinaryData.prototype.readInteger = function() {
  * @expose
  * @return {number} The 32-bit unsigned integer that was read.
  */
-org.apache.flex.utils.BinaryData.prototype.readUnsignedInteger =
+org_apache_flex_utils_BinaryData.prototype.readUnsignedInteger =
     function() {
   var view;
 
@@ -173,7 +173,7 @@ org.apache.flex.utils.BinaryData.prototype.readUnsignedInteger =
  * @expose
  * @return {number} The offset to write to or read from.
  */
-org.apache.flex.utils.BinaryData.prototype.get_position = function() {
+org_apache_flex_utils_BinaryData.prototype.get_position = function() {
   return this.position_;
 };
 
@@ -182,7 +182,7 @@ org.apache.flex.utils.BinaryData.prototype.get_position = function() {
  * @expose
  * @param {number} value The offset to write to or read from.
  */
-org.apache.flex.utils.BinaryData.prototype.set_position = function(value) {
+org_apache_flex_utils_BinaryData.prototype.set_position = function(value) {
   this.position_ = value;
 };
 
@@ -191,7 +191,7 @@ org.apache.flex.utils.BinaryData.prototype.set_position = function(value) {
  * @expose
  * @return {number} The offset to write to or read from.
  */
-org.apache.flex.utils.BinaryData.prototype.get_length = function() {
+org_apache_flex_utils_BinaryData.prototype.get_length = function() {
   return this.data_.byteLength;
 };
 
@@ -200,7 +200,7 @@ org.apache.flex.utils.BinaryData.prototype.get_length = function() {
  * @expose
  * @return {number} The number of bytes that can still be read.
  */
-org.apache.flex.utils.BinaryData.prototype.get_bytesAvailable = function() {
+org_apache_flex_utils_BinaryData.prototype.get_bytesAvailable = function() {
   return this.data_.byteLength - this.position_;
 };
 
@@ -209,7 +209,7 @@ org.apache.flex.utils.BinaryData.prototype.get_bytesAvailable = function() {
  * @expose
  * @param {number} extra The number of bytes to add to the buffer.
  */
-org.apache.flex.utils.BinaryData.prototype.growBuffer = function(extra) {
+org_apache_flex_utils_BinaryData.prototype.growBuffer = function(extra) {
   var newBuffer, newView, view, i, n;
 
   if (this.position_ >= this.data_.byteLength)

http://git-wip-us.apache.org/repos/asf/flex-asjs/blob/49f207c4/frameworks/js/FlexJS/src/org/apache/flex/utils/EffectTimer.js
----------------------------------------------------------------------
diff --git a/frameworks/js/FlexJS/src/org/apache/flex/utils/EffectTimer.js b/frameworks/js/FlexJS/src/org/apache/flex/utils/EffectTimer.js
index 1ed7592..79d9d68 100644
--- a/frameworks/js/FlexJS/src/org/apache/flex/utils/EffectTimer.js
+++ b/frameworks/js/FlexJS/src/org/apache/flex/utils/EffectTimer.js
@@ -12,22 +12,22 @@
  * limitations under the License.
  */
 
-goog.provide('org.apache.flex.utils.EffectTimer');
+goog.provide('org_apache_flex_utils_EffectTimer');
 
-goog.require('org.apache.flex.core.IEffectTimer');
-goog.require('org.apache.flex.core.ValuesManager');
-goog.require('org.apache.flex.events.EventDispatcher');
-goog.require('org.apache.flex.events.ValueEvent');
+goog.require('org_apache_flex_core_IEffectTimer');
+goog.require('org_apache_flex_core_ValuesManager');
+goog.require('org_apache_flex_events_EventDispatcher');
+goog.require('org_apache_flex_events_ValueEvent');
 
 
 
 /**
  * @constructor
- * @extends {org.apache.flex.events.EventDispatcher}
+ * @extends {org_apache_flex_events_EventDispatcher}
  * @suppress {checkTypes}
  */
-org.apache.flex.utils.EffectTimer = function() {
-  org.apache.flex.utils.EffectTimer.base(this, 'constructor');
+org_apache_flex_utils_EffectTimer = function() {
+  org_apache_flex_utils_EffectTimer.base(this, 'constructor');
 
   /**
    * @protected
@@ -39,12 +39,12 @@ org.apache.flex.utils.EffectTimer = function() {
    * @protected
    * @type {number}
    */
-  this._delay = org.apache.flex.core.ValuesManager.valuesImpl.getValue(this,
+  this._delay = org_apache_flex_core_ValuesManager.valuesImpl.getValue(this,
                                                         'effectTimerInterval');
 
 };
-goog.inherits(org.apache.flex.utils.EffectTimer,
-    org.apache.flex.events.EventDispatcher);
+goog.inherits(org_apache_flex_utils_EffectTimer,
+    org_apache_flex_events_EventDispatcher);
 
 
 /**
@@ -52,17 +52,17 @@ goog.inherits(org.apache.flex.utils.EffectTimer,
  *
  * @type {Object.<string, Array.<Object>>}
  */
-org.apache.flex.utils.EffectTimer.prototype.FLEXJS_CLASS_INFO =
+org_apache_flex_utils_EffectTimer.prototype.FLEXJS_CLASS_INFO =
     { names: [{ name: 'EffectTimer',
-               qName: 'org.apache.flex.utils.EffectTimer'}],
-        interfaces: [org.apache.flex.core.IEffectTimer] };
+               qName: 'org_apache_flex_utils_EffectTimer'}],
+        interfaces: [org_apache_flex_core_IEffectTimer] };
 
 
 /**
  * @expose
  * Stops the timer.
  */
-org.apache.flex.utils.EffectTimer.prototype.stop = function() {
+org_apache_flex_utils_EffectTimer.prototype.stop = function() {
   clearInterval(this.timerInterval);
   this.timerInterval = -1;
 };
@@ -73,7 +73,7 @@ org.apache.flex.utils.EffectTimer.prototype.stop = function() {
  * Starts the timer.
  * @return {number} The start time.
  */
-org.apache.flex.utils.EffectTimer.prototype.start = function() {
+org_apache_flex_utils_EffectTimer.prototype.start = function() {
   this.timerInterval =
       setInterval(goog.bind(this.timerHandler, this), this._delay);
   var d = new Date();
@@ -84,10 +84,10 @@ org.apache.flex.utils.EffectTimer.prototype.start = function() {
 /**
  * @protected
  */
-org.apache.flex.utils.EffectTimer.prototype.timerHandler =
+org_apache_flex_utils_EffectTimer.prototype.timerHandler =
     function() {
   var d = new Date();
-  this.dispatchEvent(new org.apache.flex.events.ValueEvent('update', d.getTime()));
+  this.dispatchEvent(new org_apache_flex_events_ValueEvent('update', d.getTime()));
 
 };
 

http://git-wip-us.apache.org/repos/asf/flex-asjs/blob/49f207c4/frameworks/js/FlexJS/src/org/apache/flex/utils/Language.js
----------------------------------------------------------------------
diff --git a/frameworks/js/FlexJS/src/org/apache/flex/utils/Language.js b/frameworks/js/FlexJS/src/org/apache/flex/utils/Language.js
index e88f6a4..d697751 100644
--- a/frameworks/js/FlexJS/src/org/apache/flex/utils/Language.js
+++ b/frameworks/js/FlexJS/src/org/apache/flex/utils/Language.js
@@ -12,14 +12,14 @@
  * limitations under the License.
  */
 
-goog.provide('org.apache.flex.utils.Language');
+goog.provide('org_apache_flex_utils_Language');
 
 
 
 /**
  * @constructor
  */
-org.apache.flex.utils.Language = function() {
+org_apache_flex_utils_Language = function() {
 };
 
 
@@ -28,9 +28,9 @@ org.apache.flex.utils.Language = function() {
  *
  * @type {Object.<string, Array.<Object>>}
  */
-org.apache.flex.utils.Language.prototype.FLEXJS_CLASS_INFO =
+org_apache_flex_utils_Language.prototype.FLEXJS_CLASS_INFO =
     { names: [{ name: 'Language',
-                qName: 'org.apache.flex.utils.Language'}] };
+                qName: 'org_apache_flex_utils_Language'}] };
 
 
 /**
@@ -46,12 +46,12 @@ org.apache.flex.utils.Language.prototype.FLEXJS_CLASS_INFO =
  * @return {?} Returns the lefthand operand if it is of the
  *             type of the righthand operand, otherwise null.
  */
-org.apache.flex.utils.Language.as = function(leftOperand, rightOperand, opt_coercion) {
+org_apache_flex_utils_Language.as = function(leftOperand, rightOperand, opt_coercion) {
   var error, itIs, message;
 
   opt_coercion = (opt_coercion !== undefined) ? opt_coercion : false;
 
-  itIs = org.apache.flex.utils.Language.is(leftOperand, rightOperand);
+  itIs = org_apache_flex_utils_Language.is(leftOperand, rightOperand);
 
   if (!itIs && opt_coercion) {
     message = 'Type Coercion failed';
@@ -74,7 +74,7 @@ org.apache.flex.utils.Language.as = function(leftOperand, rightOperand, opt_coer
  * @param {?} value The value to be cast.
  * @return {number}
  */
-org.apache.flex.utils.Language._int = function(value) {
+org_apache_flex_utils_Language._int = function(value) {
   return value >> 0;
 };
 
@@ -89,7 +89,7 @@ org.apache.flex.utils.Language._int = function(value) {
  *     binary operator in AS3.
  * @return {boolean}
  */
-org.apache.flex.utils.Language.is = function(leftOperand, rightOperand) {
+org_apache_flex_utils_Language.is = function(leftOperand, rightOperand) {
   var checkInterfaces, superClass;
 
   if (!leftOperand)
@@ -157,7 +157,7 @@ org.apache.flex.utils.Language.is = function(leftOperand, rightOperand) {
  * @expose
  * @param {string=} opt_value The message to be written to the console.
  */
-org.apache.flex.utils.Language.trace = function(opt_value) {
+org_apache_flex_utils_Language.trace = function(opt_value) {
   var theConsole;
 
   opt_value = (opt_value !== undefined) ? opt_value : '';
@@ -184,7 +184,7 @@ org.apache.flex.utils.Language.trace = function(opt_value) {
  * @param {?} value The value to be cast.
  * @return {number}
  */
-org.apache.flex.utils.Language.uint = function(value) {
+org_apache_flex_utils_Language.uint = function(value) {
   return value >>> 0;
 };
 
@@ -197,7 +197,7 @@ org.apache.flex.utils.Language.uint = function(value) {
  * @param {string} prop The name of a property.
  * @return {number}
  */
-org.apache.flex.utils.Language.preincrement = function(obj, prop) {
+org_apache_flex_utils_Language.preincrement = function(obj, prop) {
   var value = obj['get_' + prop]() + 1;
   obj['set_' + prop](value);
   return value;
@@ -212,7 +212,7 @@ org.apache.flex.utils.Language.preincrement = function(obj, prop) {
  * @param {string} prop The name of a property.
  * @return {number}
  */
-org.apache.flex.utils.Language.predecrement = function(obj, prop) {
+org_apache_flex_utils_Language.predecrement = function(obj, prop) {
   var value = obj['get_' + prop]() - 1;
   obj['set_' + prop](value);
   return value;
@@ -227,7 +227,7 @@ org.apache.flex.utils.Language.predecrement = function(obj, prop) {
  * @param {string} prop The name of a property.
  * @return {number}
  */
-org.apache.flex.utils.Language.postincrement = function(obj, prop) {
+org_apache_flex_utils_Language.postincrement = function(obj, prop) {
   var value = obj['get_' + prop]();
   obj['set_' + prop](value + 1);
   return value;
@@ -242,7 +242,7 @@ org.apache.flex.utils.Language.postincrement = function(obj, prop) {
  * @param {string} prop The name of a property.
  * @return {number}
  */
-org.apache.flex.utils.Language.postdecrement = function(obj, prop) {
+org_apache_flex_utils_Language.postdecrement = function(obj, prop) {
   var value = obj['get_' + prop]();
   obj['set_' + prop](value + 1);
   return value;

http://git-wip-us.apache.org/repos/asf/flex-asjs/blob/49f207c4/frameworks/js/FlexJS/src/org/apache/flex/utils/MXMLDataInterpreter.js
----------------------------------------------------------------------
diff --git a/frameworks/js/FlexJS/src/org/apache/flex/utils/MXMLDataInterpreter.js b/frameworks/js/FlexJS/src/org/apache/flex/utils/MXMLDataInterpreter.js
index edb40c3..95f95da 100644
--- a/frameworks/js/FlexJS/src/org/apache/flex/utils/MXMLDataInterpreter.js
+++ b/frameworks/js/FlexJS/src/org/apache/flex/utils/MXMLDataInterpreter.js
@@ -12,14 +12,14 @@
  * limitations under the License.
  */
 
-goog.provide('org.apache.flex.utils.MXMLDataInterpreter');
+goog.provide('org_apache_flex_utils_MXMLDataInterpreter');
 
 
 
 /**
  * @constructor
  */
-org.apache.flex.utils.MXMLDataInterpreter = function() {
+org_apache_flex_utils_MXMLDataInterpreter = function() {
 };
 
 
@@ -28,9 +28,9 @@ org.apache.flex.utils.MXMLDataInterpreter = function() {
  *
  * @type {Object.<string, Array.<Object>>}
  */
-org.apache.flex.utils.MXMLDataInterpreter.prototype.FLEXJS_CLASS_INFO =
+org_apache_flex_utils_MXMLDataInterpreter.prototype.FLEXJS_CLASS_INFO =
     { names: [{ name: 'MXMLDataInterpreter',
-                qName: 'org.apache.flex.utils.MXMLDataInterpreter'}] };
+                qName: 'org_apache_flex_utils_MXMLDataInterpreter'}] };
 
 
 /**
@@ -38,7 +38,7 @@ org.apache.flex.utils.MXMLDataInterpreter.prototype.FLEXJS_CLASS_INFO =
  * @param {Array} data The data array.
  * @return {Object} The generated object.
  */
-org.apache.flex.utils.MXMLDataInterpreter.generateMXMLObject =
+org_apache_flex_utils_MXMLDataInterpreter.generateMXMLObject =
     function(document, data) {
   var assignComp, Cls, comp, generateMXMLArray, generateMXMLObject, i, id, j, m,
       name, simple, value;
@@ -48,12 +48,12 @@ org.apache.flex.utils.MXMLDataInterpreter.generateMXMLObject =
   comp = new Cls();
 
   generateMXMLArray =
-      org.apache.flex.utils.MXMLDataInterpreter.generateMXMLArray;
+      org_apache_flex_utils_MXMLDataInterpreter.generateMXMLArray;
   generateMXMLObject =
-      org.apache.flex.utils.MXMLDataInterpreter.generateMXMLObject;
+      org_apache_flex_utils_MXMLDataInterpreter.generateMXMLObject;
 
   if (comp.addBead)
-    org.apache.flex.utils.MXMLDataInterpreter.initializeStrandBasedObject(document, null, comp, data, i);
+    org_apache_flex_utils_MXMLDataInterpreter.initializeStrandBasedObject(document, null, comp, data, i);
   else {
     m = data[i++]; // num props
     for (j = 0; j < m; j++) {
@@ -109,7 +109,7 @@ org.apache.flex.utils.MXMLDataInterpreter.generateMXMLObject =
  * @param {Array} data The data array.
  * @return {Array} The generated array.
  */
-org.apache.flex.utils.MXMLDataInterpreter.generateMXMLArray =
+org_apache_flex_utils_MXMLDataInterpreter.generateMXMLArray =
     function(document, parent, data) {
   var comps = [];
 
@@ -119,7 +119,7 @@ org.apache.flex.utils.MXMLDataInterpreter.generateMXMLArray =
     var cls = data[i++];
     var comp = new cls();
 
-    i = org.apache.flex.utils.MXMLDataInterpreter.initializeStrandBasedObject(document, parent, comp, data, i);
+    i = org_apache_flex_utils_MXMLDataInterpreter.initializeStrandBasedObject(document, parent, comp, data, i);
 
     comps.push(comp);
   }
@@ -136,15 +136,15 @@ org.apache.flex.utils.MXMLDataInterpreter.generateMXMLArray =
  * @param {number} i The offset into data.
  * @return {number} The new offset into the data.
  */
-org.apache.flex.utils.MXMLDataInterpreter.initializeStrandBasedObject =
+org_apache_flex_utils_MXMLDataInterpreter.initializeStrandBasedObject =
     function(document, parent, comp, data, i) {
   var bead, beadOffset, beads, children, Cls, generateMXMLArray,
       generateMXMLObject, id, j, k, l, m, n, name, self, simple, value, dispatchBeadsAdded;
 
   generateMXMLArray =
-      org.apache.flex.utils.MXMLDataInterpreter.generateMXMLArray;
+      org_apache_flex_utils_MXMLDataInterpreter.generateMXMLArray;
   generateMXMLObject =
-      org.apache.flex.utils.MXMLDataInterpreter.generateMXMLObject;
+      org_apache_flex_utils_MXMLDataInterpreter.generateMXMLObject;
 
   id = null;
 
@@ -270,14 +270,14 @@ org.apache.flex.utils.MXMLDataInterpreter.initializeStrandBasedObject =
   if (children && comp['setMXMLDescriptor']) {
     comp['setMXMLDescriptor'](document, children);
   }
-  if (parent && org.apache.flex.utils.Language.is(comp,
-      org.apache.flex.core.IUIBase)) {
+  if (parent && org_apache_flex_utils_Language.is(comp,
+      org_apache_flex_core_IUIBase)) {
     parent.addElement(comp);
   }
 
   if (children) {
     if (!comp['setMXMLDescriptor']) {
-      self = org.apache.flex.utils.MXMLDataInterpreter;
+      self = org_apache_flex_utils_MXMLDataInterpreter;
       self.generateMXMLInstances(
             document, comp, children);
       if (typeof comp.childrenAdded === 'function')
@@ -311,10 +311,10 @@ org.apache.flex.utils.MXMLDataInterpreter.initializeStrandBasedObject =
  * @param {Object} parent The parent object.
  * @param {Array} data The data array.
  */
-org.apache.flex.utils.MXMLDataInterpreter.generateMXMLInstances =
+org_apache_flex_utils_MXMLDataInterpreter.generateMXMLInstances =
     function(document, parent, data) {
   if (data) {
-    org.apache.flex.utils.MXMLDataInterpreter.generateMXMLArray(
+    org_apache_flex_utils_MXMLDataInterpreter.generateMXMLArray(
         document, parent, data);
   }
 };
@@ -325,7 +325,7 @@ org.apache.flex.utils.MXMLDataInterpreter.generateMXMLInstances =
  * @param {Object} host The MXML object.
  * @param {Array} data The data array.
  */
-org.apache.flex.utils.MXMLDataInterpreter.generateMXMLProperties =
+org_apache_flex_utils_MXMLDataInterpreter.generateMXMLProperties =
     function(host, data) {
   var bead, beadOffset, beads, generateMXMLArray, generateMXMLObject, i, id, j,
       k, l, m, name, simple, value;
@@ -338,9 +338,9 @@ org.apache.flex.utils.MXMLDataInterpreter.generateMXMLProperties =
   id = null;
 
   generateMXMLArray =
-      org.apache.flex.utils.MXMLDataInterpreter.generateMXMLArray;
+      org_apache_flex_utils_MXMLDataInterpreter.generateMXMLArray;
   generateMXMLObject =
-      org.apache.flex.utils.MXMLDataInterpreter.generateMXMLObject;
+      org_apache_flex_utils_MXMLDataInterpreter.generateMXMLObject;
 
   m = data[i++]; // num props
   beadOffset = i + (m - 1) * 3;

http://git-wip-us.apache.org/repos/asf/flex-asjs/blob/49f207c4/frameworks/js/FlexJS/src/org/apache/flex/utils/MixinManager.js
----------------------------------------------------------------------
diff --git a/frameworks/js/FlexJS/src/org/apache/flex/utils/MixinManager.js b/frameworks/js/FlexJS/src/org/apache/flex/utils/MixinManager.js
index 445ddbe..875fbe6 100644
--- a/frameworks/js/FlexJS/src/org/apache/flex/utils/MixinManager.js
+++ b/frameworks/js/FlexJS/src/org/apache/flex/utils/MixinManager.js
@@ -12,17 +12,17 @@
  * limitations under the License.
  */
 
-goog.provide('org.apache.flex.utils.MixinManager');
+goog.provide('org_apache_flex_utils_MixinManager');
 
 
 
 /**
  * @constructor
- * @implements {org.apache.flex.core.IBead}
+ * @implements {org_apache_flex_core_IBead}
  * Initialize mixins.
  * Compiler may not be generating list of mixins right now.
  */
-org.apache.flex.utils.MixinManager = function() {
+org_apache_flex_utils_MixinManager = function() {
 };
 
 
@@ -31,17 +31,17 @@ org.apache.flex.utils.MixinManager = function() {
  *
  * @type {Object.<string, Array.<Object>>}
  */
-org.apache.flex.utils.MixinManager.prototype.FLEXJS_CLASS_INFO =
+org_apache_flex_utils_MixinManager.prototype.FLEXJS_CLASS_INFO =
     { names: [{ name: 'MixinManager',
-                qName: 'org.apache.flex.utils.MixinManager'}],
-     interfaces: [org.apache.flex.core.IBead]};
+                qName: 'org_apache_flex_utils_MixinManager'}],
+     interfaces: [org_apache_flex_core_IBead]};
 
 
 /**
  * @expose
  * @param {Object} value The new host.
  */
-org.apache.flex.utils.MixinManager.prototype.set_strand =
+org_apache_flex_utils_MixinManager.prototype.set_strand =
 function(value) {
   this.strand_ = value;
 

http://git-wip-us.apache.org/repos/asf/flex-asjs/blob/49f207c4/frameworks/js/FlexJS/src/org/apache/flex/utils/PointUtils.js
----------------------------------------------------------------------
diff --git a/frameworks/js/FlexJS/src/org/apache/flex/utils/PointUtils.js b/frameworks/js/FlexJS/src/org/apache/flex/utils/PointUtils.js
index 6c03884..0d6ea8d 100644
--- a/frameworks/js/FlexJS/src/org/apache/flex/utils/PointUtils.js
+++ b/frameworks/js/FlexJS/src/org/apache/flex/utils/PointUtils.js
@@ -12,16 +12,16 @@
  * limitations under the License.
  */
 
-goog.provide('org.apache.flex.utils.PointUtils');
+goog.provide('org_apache_flex_utils_PointUtils');
 
-goog.require('org.apache.flex.geom.Point');
+goog.require('org_apache_flex_geom_Point');
 
 
 
 /**
  * @constructor
  */
-org.apache.flex.utils.PointUtils = function() {
+org_apache_flex_utils_PointUtils = function() {
 };
 
 
@@ -30,18 +30,18 @@ org.apache.flex.utils.PointUtils = function() {
  *
  * @type {Object.<string, Array.<Object>>}
  */
-org.apache.flex.utils.PointUtils.prototype.FLEXJS_CLASS_INFO =
+org_apache_flex_utils_PointUtils.prototype.FLEXJS_CLASS_INFO =
     { names: [{ name: 'PointUtils',
-                qName: 'org.apache.flex.utils.PointUtils' }] };
+                qName: 'org_apache_flex_utils_PointUtils' }] };
 
 
 /**
  * @expose
  * @param {org.apache.flex.geom.Point} point The Point to be converted.
  * @param {Object} local The object used as reference.
  * @return {org.apache.flex.geom.Point} The converted Point.
  */
-org.apache.flex.utils.PointUtils.globalToLocal =
+org_apache_flex_utils_PointUtils.globalToLocal =
     function(point, local) {
   var x = point.x, y = point.y;
   var element = local.element;
@@ -57,17 +57,17 @@ org.apache.flex.utils.PointUtils.globalToLocal =
     }
   }
   while (element);
-  return new org.apache.flex.geom.Point(x, y);
+  return new org_apache_flex_geom_Point(x, y);
 };
 
 
 /**
  * @expose
  * @param {org.apache.flex.geom.Point} point The Point to be converted.
  * @param {Object} local The object used as reference.
  * @return {org.apache.flex.geom.Point} The converted Point.
  */
-org.apache.flex.utils.PointUtils.localToGlobal =
+org_apache_flex_utils_PointUtils.localToGlobal =
     function(point, local) {
   var x = point.x, y = point.y;
   var element = local.element;
@@ -83,5 +83,5 @@ org.apache.flex.utils.PointUtils.localToGlobal =
     }
   }
   while (element);
-  return new org.apache.flex.geom.Point(x, y);
+  return new org_apache_flex_geom_Point(x, y);
 };
@@ -30,18 +30,18 @@ org.apache.flex.utils.PointUtils = function() {
 /**
  * @expose
- * @param {org.apache.flex.geom.Point} point The Point to be converted.
+ * @param {org_apache_flex_geom_Point} point The Point to be converted.
  * @param {Object} local The object used as reference.
@@ -30,18 +30,18 @@ org.apache.flex.utils.PointUtils = function() {
  * @param {Object} local The object used as reference.
- * @return {org.apache.flex.geom.Point} The converted Point.
+ * @return {org_apache_flex_geom_Point} The converted Point.
  */
@@ -57,17 +57,17 @@ org.apache.flex.utils.PointUtils.globalToLocal =
 /**
  * @expose
- * @param {org.apache.flex.geom.Point} point The Point to be converted.
+ * @param {org_apache_flex_geom_Point} point The Point to be converted.
  * @param {Object} local The object used as reference.
@@ -57,17 +57,17 @@ org.apache.flex.utils.PointUtils.globalToLocal =
  * @param {Object} local The object used as reference.
- * @return {org.apache.flex.geom.Point} The converted Point.
+ * @return {org_apache_flex_geom_Point} The converted Point.
  */